(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    201394,       4200]
NotebookOptionsPosition[    198934,       4123]
NotebookOutlinePosition[    199353,       4139]
CellTagsIndexPosition[    199310,       4136]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Here we produce, one by one, the nine graphs that appear in Figure \
3 as a 3x3 grid of images.  Each shows equilibrium values of N and P, \
according to our model.  The following parameters stay the same throughout \
each of the nine images:\n\nNInput = I",
  Background->RGBColor[0.9, 1, 1]],
 StyleBox["N",
  FontSize->11,
  Background->RGBColor[0.9, 1, 1]],
 StyleBox[" (in the paper) = 0.2\ns = 0.01\nf = 0.88\nk = 30.0\nm = 10.0\n\
\[Alpha] = 0.2\nq = 2.0\n\nThe following parameters vary throughout the \
images:\n\nPInput = I",
  Background->RGBColor[0.9, 1, 1]],
 StyleBox["P",
  FontSize->11,
  Background->RGBColor[0.9, 1, 1]],
 StyleBox[" = 0.004, 0.008, 0.012\nr = 0.15, 0.25, 0.35\n\nEach possible \
combination of PInput and r appears in one image.",
  Background->RGBColor[0.9, 1, 1]]
}], "Text",
 CellChangeTimes->{{3.610271043974658*^9, 3.6102710862540765`*^9}, {
  3.6223886424589643`*^9, 3.622388720439076*^9}, {3.622388795766714*^9, 
  3.622388983486995*^9}, {3.6223890290170603`*^9, 3.622389045727086*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "NInput", ",", "PInput", ",", "sink", ",", "f", ",", "r", ",", "m", ",", 
    "k", ",", "q", ",", "N", ",", "P", ",", "x", ",", "y"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NInput", "=", ".2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PInput", "=", ".004"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sink", "=", ".01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f", "=", "0.88"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r", "=", ".15"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"m", "=", "10"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"k", "=", "30.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"q", "=", "2.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "=", "0.2"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"cp1", "=", 
    RowBox[{"ContourPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"NInput", "-", 
          RowBox[{"sink", "*", "Nit"}], "+", 
          RowBox[{"f", "*", "P", "*", 
           FractionBox[
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"-", "\[Alpha]"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"Nit", "/", "P"}], " ", "-", "k"}], ")"}]}]], 
            RowBox[{"1", "+", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               RowBox[{"-", "\[Alpha]"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Nit", "/", "P"}], " ", "-", "k"}], ")"}]}]]}]]}]}], 
         "\[Equal]", "0"}], ",", 
        RowBox[{
         RowBox[{"PInput", "-", 
          RowBox[{"sink", "*", "P"}], "+", 
          FractionBox[
           RowBox[{"r", "*", 
            RowBox[{"P", "^", "q"}]}], 
           RowBox[{
            RowBox[{"m", "^", "q"}], "+", 
            RowBox[{"P", "^", "q"}]}]]}], "\[Equal]", "0"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Nit", ",", "0", ",", "1200"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"P", ",", "0", ",", "35"}], "}"}], ",", 
      RowBox[{"ContourStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Blue"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Red"}], "}"}]}], 
        "}"}]}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<N\>\"", ",", "\"\<P\>\""}], "}"}]}], ",", 
      RowBox[{"LabelStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Black", ",", 
         RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
         RowBox[{"FontSize", "\[Rule]", "14"}]}], "]"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot1", "=", 
   RowBox[{"Show", "[", "cp1", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{"\"\<figure1A pt004.eps\>\"", ",", "%"}], "]"}]}], "Input",
 CellChangeTimes->{{3.564351280756055*^9, 3.5643513383918858`*^9}, {
  3.564351660495411*^9, 3.564351692329215*^9}, {3.564351770552031*^9, 
  3.5643517737433558`*^9}, {3.564351942980723*^9, 3.564351948370141*^9}, {
  3.5644058266769114`*^9, 3.5644058268429117`*^9}, {3.5644058975049114`*^9, 
  3.5644058976719112`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Clear", "::", "wrsym"}], "MessageName"], ":", 
  " ", "\<\"Symbol \[NoBreak]\\!\\(N\\)\[NoBreak] is Protected. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/wrsym\\\", \
ButtonNote -> \\\"Clear::wrsym\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5644060833787766`*^9}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxdlwk41dkbx5FC+itLq+y7KFxky/0yoUjIbm5pITvXWvZrX7Lcq10RY2mm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   "], {{}, {}, 
    TagBox[
     TooltipBox[
      {RGBColor[0, 0, 1], Thickness[0.01], 
       LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
         19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 
        36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 
        53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 
        70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 
        87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
        103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 
        117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 
        131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 142, 143, 144, 
        145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 
        159, 160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 
        173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 
        187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197}]},
      RowBox[{
        RowBox[{
          RowBox[{"0.2`", "\[VeryThinSpace]"}], "-", 
          RowBox[{"0.01`", " ", "Nit"}], "+", 
          FractionBox[
           RowBox[{"0.88`", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
                RowBox[{"-", "0.2`"}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"-", "30.`"}], "+", 
                    FractionBox["Nit", "P"]}], ")"}]}]], " ", "P"}], 
           RowBox[{"1", "+", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
                RowBox[{"-", "0.2`"}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"-", "30.`"}], "+", 
                    FractionBox["Nit", "P"]}], ")"}]}]]}]]}], "\[Equal]", 
        "0"}]],
     Annotation[#, 
      0.2 - 0.01 $CellContext`Nit + ((0.88 
          E^((-0.2) (-30. + $CellContext`Nit/$CellContext`P)))/(1 + 
         E^((-0.2) (-30. + $CellContext`Nit/$CellContext`P)))) $CellContext`P == 
      0, "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[1, 0, 0], Thickness[0.01], LineBox[CompressedData["
1:eJwNz0VWQgEAAMCPii1iB0qZeByP4Htu9ZY22IHd3YitMIs5wKQmpsenQkEQ
TDLDLHPMs8AiS2TJscwKq6yxzgabbLHNDnl22WOfAw454pgTTjnjnAsuueKa
G265454HHnnimRdeKfBGkXc++OSLb3745Y9/SgTCISqopIow1dRQSx31NNBI
ExGaidJCK22000EnXXTTQy8x+ugnToIkKdIMMMgQw4wwSoYxymghORw=
        "]]},
      RowBox[{
        RowBox[{
          RowBox[{"0.004`", "\[VeryThinSpace]"}], "-", 
          RowBox[{"0.01`", " ", "P"}], "+", 
          FractionBox[
           RowBox[{"0.15`", " ", 
             SuperscriptBox["P", "2.`"]}], 
           RowBox[{
             RowBox[{"100.`", "\[VeryThinSpace]"}], "+", 
             SuperscriptBox["P", "2.`"]}]]}], "\[Equal]", "0"}]],
     Annotation[#, 
      0.004 - 0.01 $CellContext`P + 
       0.15 ($CellContext`P^2./(100. + $CellContext`P^2.)) == 0, 
      "Tooltip"]& ]}],
  AspectRatio->1,
  Frame->True,
  FrameLabel->{
    FormBox["\"N\"", TraditionalForm], 
    FormBox["\"P\"", TraditionalForm]},
  LabelStyle->Directive[
    GrayLevel[0], FontFamily -> "Helvetica", FontSize -> 14],
  PlotRange->{{0, 1200}, {0, 35}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5644060834567842`*^9}],

Cell[BoxData["\<\"figure1A pt004.eps\"\>"], "Output",
 CellChangeTimes->{3.564406083672806*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "NInput", ",", "PInput", ",", "sink", ",", "f", ",", "r", ",", "m", ",", 
    "k", ",", "q", ",", "N", ",", "P", ",", "x", ",", "y"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NInput", "=", ".2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PInput", "=", ".004"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sink", "=", ".01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f", "=", "0.88"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r", "=", ".25"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"m", "=", "10"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"k", "=", "30.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"q", "=", "2.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "=", "0.2"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"cp2", "=", 
    RowBox[{"ContourPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"NInput", "-", 
          RowBox[{"sink", "*", "Nit"}], "+", 
          RowBox[{"f", "*", "P", "*", 
           FractionBox[
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"-", "\[Alpha]"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"Nit", "/", "P"}], " ", "-", "k"}], ")"}]}]], 
            RowBox[{"1", "+", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               RowBox[{"-", "\[Alpha]"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Nit", "/", "P"}], " ", "-", "k"}], ")"}]}]]}]]}]}], 
         "\[Equal]", "0"}], ",", 
        RowBox[{
         RowBox[{"PInput", "-", 
          RowBox[{"sink", "*", "P"}], "+", 
          FractionBox[
           RowBox[{"r", "*", 
            RowBox[{"P", "^", "q"}]}], 
           RowBox[{
            RowBox[{"m", "^", "q"}], "+", 
            RowBox[{"P", "^", "q"}]}]]}], "\[Equal]", "0"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Nit", ",", "0", ",", "1200"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"P", ",", "0", ",", "35"}], "}"}], ",", 
      RowBox[{"ContourStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Blue"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Red"}], "}"}]}], 
        "}"}]}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<N\>\"", ",", "\"\<P\>\""}], "}"}]}], ",", 
      RowBox[{"LabelStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Black", ",", 
         RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
         RowBox[{"FontSize", "\[Rule]", "14"}]}], "]"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot2", "=", 
   RowBox[{"Show", "[", "cp2", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{"\"\<figure1B pt004.eps\>\"", ",", "%"}], "]"}]}], "Input",
 CellChangeTimes->{{3.564351280756055*^9, 3.5643513383918858`*^9}, {
  3.564351660495411*^9, 3.564351692329215*^9}, {3.564351770552031*^9, 
  3.5643517737433558`*^9}, {3.564351942980723*^9, 3.564351948370141*^9}, {
  3.5644058290929117`*^9, 3.5644058665189114`*^9}, {3.5644059002009115`*^9, 
  3.5644059084729114`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Clear", "::", "wrsym"}], "MessageName"], ":", 
  " ", "\<\"Symbol \[NoBreak]\\!\\(N\\)\[NoBreak] is Protected. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/wrsym\\\", \
ButtonNote -> \\\"Clear::wrsym\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.56440608381182*^9}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxdmAk0lO0bxpFC+iuSkmzZl0qGsmVuvmQpkX2NLFmHsWcf29iZ0deeIu1F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   "], {{}, {}, 
    TagBox[
     TooltipBox[
      {RGBColor[0, 0, 1], Thickness[0.01], 
       LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
         19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 
        36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 
        53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 
        70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 
        87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
        103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 
        117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 
        131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 142, 143, 144, 
        145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 
        159, 160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 
        173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 
        187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197}]},
      RowBox[{
        RowBox[{
          RowBox[{"0.2`", "\[VeryThinSpace]"}], "-", 
          RowBox[{"0.01`", " ", "Nit"}], "+", 
          FractionBox[
           RowBox[{"0.88`", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
                RowBox[{"-", "0.2`"}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"-", "30.`"}], "+", 
                    FractionBox["Nit", "P"]}], ")"}]}]], " ", "P"}], 
           RowBox[{"1", "+", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
                RowBox[{"-", "0.2`"}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"-", "30.`"}], "+", 
                    FractionBox["Nit", "P"]}], ")"}]}]]}]]}], "\[Equal]", 
        "0"}]],
     Annotation[#, 
      0.2 - 0.01 $CellContext`Nit + ((0.88 
          E^((-0.2) (-30. + $CellContext`Nit/$CellContext`P)))/(1 + 
         E^((-0.2) (-30. + $CellContext`Nit/$CellContext`P)))) $CellContext`P == 
      0, "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[1, 0, 0], Thickness[0.01], LineBox[CompressedData["
1:eJwNz1k2QgEAANBXKkRESP21Jee0AQtglzI1UeYxlTESIQr34y7g5lbXV9ZC
QRDk2aDAJltss8MuRUqUqVBlj31q1DngkCOOOeGUM8654JIrrmlwQ5MWbW65
454HHnmiwzMvdHmlxxvv9Pngky8GfPPDkBG//BEIhwgzRoQoMcaZYJI4U0yT
YIZZkswxT4oFFlkizTIZsvwDUr821A==
        "]], LineBox[CompressedData["
1:eJwV0Nk2QgEAQNHbd4QkypSMSYOQoYhIoTKVyNDw/292D3ut83yivUl9HAqC
oElYzDDLHBHmibJAjEWWiJNgmRVWWWOdJBuk2GSLbXbYZY80+2Q4IEuOPAUO
KXLEMSeUOOWMcy4oU+GSK6pcc0ONW+6oc0+DJg888kSLNh2eeeGVN97p0uOD
Pp98MeCbH375Y8iI6dQJ/0YlGUc=
        "]], LineBox[CompressedData["
1:eJwNxlVSQgEAAMDnUbySR3DGX7EFO8FCEewOLBTF7u5G5UDux85scWmopLwo
CIIyKqSSKqqpoZY66gkToYFGmmimhVbaaKeDTrroJkqMHnrpo58B4gwyRIJh
kqQYYZQxxplgkimmmWGWOeZZYJEllkmzwiprrLNBhk22yLLNDjl22WOfAw45
4pgTTjnjnAsuueKaG265454HHnnimRdeeeOdDz754ps8P/zyR4F/Zz9CaA==

        "]]},
      RowBox[{
        RowBox[{
          RowBox[{"0.004`", "\[VeryThinSpace]"}], "-", 
          RowBox[{"0.01`", " ", "P"}], "+", 
          FractionBox[
           RowBox[{"0.25`", " ", 
             SuperscriptBox["P", "2.`"]}], 
           RowBox[{
             RowBox[{"100.`", "\[VeryThinSpace]"}], "+", 
             SuperscriptBox["P", "2.`"]}]]}], "\[Equal]", "0"}]],
     Annotation[#, 
      0.004 - 0.01 $CellContext`P + 
       0.25 ($CellContext`P^2./(100. + $CellContext`P^2.)) == 0, 
      "Tooltip"]& ]}],
  AspectRatio->1,
  Frame->True,
  FrameLabel->{
    FormBox["\"N\"", TraditionalForm], 
    FormBox["\"P\"", TraditionalForm]},
  LabelStyle->Directive[
    GrayLevel[0], FontFamily -> "Helvetica", FontSize -> 14],
  PlotRange->{{0, 1200}, {0, 35}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5644060838958282`*^9}],

Cell[BoxData["\<\"figure1B pt004.eps\"\>"], "Output",
 CellChangeTimes->{3.564406084142853*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "NInput", ",", "PInput", ",", "sink", ",", "f", ",", "r", ",", "m", ",", 
    "k", ",", "q", ",", "N", ",", "P", ",", "x", ",", "y"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NInput", "=", ".2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PInput", "=", ".004"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sink", "=", ".01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f", "=", "0.88"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r", "=", ".35"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"m", "=", "10"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"k", "=", "30.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"q", "=", "2.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "=", "0.2"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"cp3", "=", 
    RowBox[{"ContourPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"NInput", "-", 
          RowBox[{"sink", "*", "Nit"}], "+", 
          RowBox[{"f", "*", "P", "*", 
           FractionBox[
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"-", "\[Alpha]"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"Nit", "/", "P"}], " ", "-", "k"}], ")"}]}]], 
            RowBox[{"1", "+", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               RowBox[{"-", "\[Alpha]"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Nit", "/", "P"}], " ", "-", "k"}], ")"}]}]]}]]}]}], 
         "\[Equal]", "0"}], ",", 
        RowBox[{
         RowBox[{"PInput", "-", 
          RowBox[{"sink", "*", "P"}], "+", 
          FractionBox[
           RowBox[{"r", "*", 
            RowBox[{"P", "^", "q"}]}], 
           RowBox[{
            RowBox[{"m", "^", "q"}], "+", 
            RowBox[{"P", "^", "q"}]}]]}], "\[Equal]", "0"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Nit", ",", "0", ",", "1200"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"P", ",", "0", ",", "35"}], "}"}], ",", 
      RowBox[{"ContourStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Blue"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Red"}], "}"}]}], 
        "}"}]}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<N\>\"", ",", "\"\<P\>\""}], "}"}]}], ",", 
      RowBox[{"LabelStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Black", ",", 
         RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
         RowBox[{"FontSize", "\[Rule]", "14"}]}], "]"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot3", "=", 
   RowBox[{"Show", "[", "cp3", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{"\"\<figure1C pt004.eps\>\"", ",", "%"}], "]"}]}], "Input",
 CellChangeTimes->{{3.564351280756055*^9, 3.5643513383918858`*^9}, {
  3.564351660495411*^9, 3.564351692329215*^9}, {3.564351770552031*^9, 
  3.5643517737433558`*^9}, {3.564351942980723*^9, 3.564351948370141*^9}, {
  3.5644058317559114`*^9, 3.564405911244911*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Clear", "::", "wrsym"}], "MessageName"], ":", 
  " ", "\<\"Symbol \[NoBreak]\\!\\(N\\)\[NoBreak] is Protected. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/wrsym\\\", \
ButtonNote -> \\\"Clear::wrsym\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5644060842348623`*^9}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxdmAk4lF0bx23ZPyRaJdmTQoNsmZsiSS9liUKI7Pu+MxhLY8zQIoW8ilJK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   "], {{}, {}, 
    TagBox[
     TooltipBox[
      {RGBColor[0, 0, 1], Thickness[0.01], 
       LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
         19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 
        36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 
        53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 
        70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 
        87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
        103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 
        117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 
        131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 142, 143, 144, 
        145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 
        159, 160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 
        173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 
        187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197}]},
      RowBox[{
        RowBox[{
          RowBox[{"0.2`", "\[VeryThinSpace]"}], "-", 
          RowBox[{"0.01`", " ", "Nit"}], "+", 
          FractionBox[
           RowBox[{"0.88`", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
                RowBox[{"-", "0.2`"}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"-", "30.`"}], "+", 
                    FractionBox["Nit", "P"]}], ")"}]}]], " ", "P"}], 
           RowBox[{"1", "+", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
                RowBox[{"-", "0.2`"}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"-", "30.`"}], "+", 
                    FractionBox["Nit", "P"]}], ")"}]}]]}]]}], "\[Equal]", 
        "0"}]],
     Annotation[#, 
      0.2 - 0.01 $CellContext`Nit + ((0.88 
          E^((-0.2) (-30. + $CellContext`Nit/$CellContext`P)))/(1 + 
         E^((-0.2) (-30. + $CellContext`Nit/$CellContext`P)))) $CellContext`P == 
      0, "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[1, 0, 0], Thickness[0.01], LineBox[CompressedData["
1:eJwNz1k2QgEAANBXKkRESP21Jee0AQtglzI1UeYxlTESIQr34y7g5lbXV9ZC
QRDk2aDAJltss8MuRUqUqVBlj31q1DngkCOOOeGUM8654JIrrmlwQ5MWbW65
454HHnmiwzMvdHmlxxvv9Pngky8GfPPDkBG//BEIhwgzRoQoMcaZYJI4U0yT
YIZZkswxT4oFFlkizTIZsvwDUr821A==
        "]], LineBox[CompressedData["
1:eJwV0FdbgQEAgNGv36FBWkRDS5TZ1CQjLSWlNOT/33RcnOd5r99Id1j7nQiC
oEVITDLFNDOEiTBLlDnmWWCRJWLEWSZBkhVWWWOdFBtsssU2O6TZJUOWPfbJ
kadAkRJlDjjkiGNOOKXCGedccMkV11SpcUOdBk1a3NLmjnseeOSJDs+80OWV
Hm+80+eDTwZ88c0P46lD/hjxDxh6Giw=
        "]], LineBox[CompressedData["
1:eJwNxlVSQgEAAMDnUbySR3DGX5mxBTvBQhHsDiwUxe7uRuU87sfObHFpqKS8
KAiCMiqkkiqqqaGWOuoJE6GBRppopoVW2ming0666CZKjB566aOfAeIMMkSC
YZKkGGGUMcaZYJIppplhljnmWWCRJZZJs8Iqa6yzQYZNtsiyzQ45dtljnwMO
OeKYE04545wLLrnimhtuueOeBx554pkXXnnjnQ8++eKbPD/88keBfwhGQzI=

        "]]},
      RowBox[{
        RowBox[{
          RowBox[{"0.004`", "\[VeryThinSpace]"}], "-", 
          RowBox[{"0.01`", " ", "P"}], "+", 
          FractionBox[
           RowBox[{"0.35`", " ", 
             SuperscriptBox["P", "2.`"]}], 
           RowBox[{
             RowBox[{"100.`", "\[VeryThinSpace]"}], "+", 
             SuperscriptBox["P", "2.`"]}]]}], "\[Equal]", "0"}]],
     Annotation[#, 
      0.004 - 0.01 $CellContext`P + 
       0.35 ($CellContext`P^2./(100. + $CellContext`P^2.)) == 0, 
      "Tooltip"]& ]}],
  AspectRatio->1,
  Frame->True,
  FrameLabel->{
    FormBox["\"N\"", TraditionalForm], 
    FormBox["\"P\"", TraditionalForm]},
  LabelStyle->Directive[
    GrayLevel[0], FontFamily -> "Helvetica", FontSize -> 14],
  PlotRange->{{0, 1200}, {0, 35}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5644060843568745`*^9}],

Cell[BoxData["\<\"figure1C pt004.eps\"\>"], "Output",
 CellChangeTimes->{3.5644060846119*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "NInput", ",", "PInput", ",", "sink", ",", "f", ",", "r", ",", "m", ",", 
    "k", ",", "q", ",", "N", ",", "P", ",", "x", ",", "y"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NInput", "=", ".2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PInput", "=", ".008"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sink", "=", ".01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f", "=", "0.88"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r", "=", ".15"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"m", "=", "10"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"k", "=", "30.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"q", "=", "2.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "=", "0.2"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"cp4", "=", 
    RowBox[{"ContourPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"NInput", "-", 
          RowBox[{"sink", "*", "Nit"}], "+", 
          RowBox[{"f", "*", "P", "*", 
           FractionBox[
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"-", "\[Alpha]"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"Nit", "/", "P"}], " ", "-", "k"}], ")"}]}]], 
            RowBox[{"1", "+", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               RowBox[{"-", "\[Alpha]"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Nit", "/", "P"}], " ", "-", "k"}], ")"}]}]]}]]}]}], 
         "\[Equal]", "0"}], ",", 
        RowBox[{
         RowBox[{"PInput", "-", 
          RowBox[{"sink", "*", "P"}], "+", 
          FractionBox[
           RowBox[{"r", "*", 
            RowBox[{"P", "^", "q"}]}], 
           RowBox[{
            RowBox[{"m", "^", "q"}], "+", 
            RowBox[{"P", "^", "q"}]}]]}], "\[Equal]", "0"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Nit", ",", "0", ",", "1200"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"P", ",", "0", ",", "35"}], "}"}], ",", 
      RowBox[{"ContourStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Blue"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Red"}], "}"}]}], 
        "}"}]}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<N\>\"", ",", "\"\<P\>\""}], "}"}]}], ",", 
      RowBox[{"LabelStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Black", ",", 
         RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
         RowBox[{"FontSize", "\[Rule]", "14"}]}], "]"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot4", "=", 
   RowBox[{"Show", "[", "cp4", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{"\"\<figure2A pt008.eps\>\"", ",", "%"}], "]"}]}], "Input",
 CellChangeTimes->{{3.564351280756055*^9, 3.5643513383918858`*^9}, {
  3.564351660495411*^9, 3.564351692329215*^9}, {3.564351770552031*^9, 
  3.5643517737433558`*^9}, {3.564351942980723*^9, 3.564351948370141*^9}, {
  3.5644059185199113`*^9, 3.5644059410999117`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Clear", "::", "wrsym"}], "MessageName"], ":", 
  " ", "\<\"Symbol \[NoBreak]\\!\\(N\\)\[NoBreak] is Protected. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/wrsym\\\", \
ButtonNote -> \\\"Clear::wrsym\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.564405344722228*^9, 3.5644060846939077`*^9}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxdlwk0ldsbxpFE+svUaJ4jFQ4y5Ty6oTSQOVESlSGOeZ45hkxH462Qq+E2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   "], {{}, {}, 
    TagBox[
     TooltipBox[
      {RGBColor[0, 0, 1], Thickness[0.01], 
       LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
         19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 
        36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 
        53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 
        70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 
        87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
        103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 
        117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 
        131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 142, 143, 144, 
        145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 
        159, 160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 
        173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 
        187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197}]},
      RowBox[{
        RowBox[{
          RowBox[{"0.2`", "\[VeryThinSpace]"}], "-", 
          RowBox[{"0.01`", " ", "Nit"}], "+", 
          FractionBox[
           RowBox[{"0.88`", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
                RowBox[{"-", "0.2`"}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"-", "30.`"}], "+", 
                    FractionBox["Nit", "P"]}], ")"}]}]], " ", "P"}], 
           RowBox[{"1", "+", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
                RowBox[{"-", "0.2`"}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"-", "30.`"}], "+", 
                    FractionBox["Nit", "P"]}], ")"}]}]]}]]}], "\[Equal]", 
        "0"}]],
     Annotation[#, 
      0.2 - 0.01 $CellContext`Nit + ((0.88 
          E^((-0.2) (-30. + $CellContext`Nit/$CellContext`P)))/(1 + 
         E^((-0.2) (-30. + $CellContext`Nit/$CellContext`P)))) $CellContext`P == 
      0, "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[1, 0, 0], Thickness[0.01], LineBox[CompressedData["
1:eJwNz2ciggEAANAvexXKJmmo+3SEDpBb2nsnsvfeIvR+vAO8ZGEqXwwFQVBg
mhlmmWOeBRZZYpkVVlljnQ022WKbHXYpsUeZfQ6ocMgRx5xwyhnnXHDJFdfc
cMsd9zzwyBPPvPDKG+988MkXVb75ocYvf/wTCIdooJEmmmmhlTba6aCTLsJE
6KaHXqLE6KOfAQYZYpgRRhkjzjgJJkiSIk2GSbLkqAO4Azib
        "]]},
      RowBox[{
        RowBox[{
          RowBox[{"0.008`", "\[VeryThinSpace]"}], "-", 
          RowBox[{"0.01`", " ", "P"}], "+", 
          FractionBox[
           RowBox[{"0.15`", " ", 
             SuperscriptBox["P", "2.`"]}], 
           RowBox[{
             RowBox[{"100.`", "\[VeryThinSpace]"}], "+", 
             SuperscriptBox["P", "2.`"]}]]}], "\[Equal]", "0"}]],
     Annotation[#, 
      0.008 - 0.01 $CellContext`P + 
       0.15 ($CellContext`P^2./(100. + $CellContext`P^2.)) == 0, 
      "Tooltip"]& ]}],
  AspectRatio->1,
  Frame->True,
  FrameLabel->{
    FormBox["\"N\"", TraditionalForm], 
    FormBox["\"P\"", TraditionalForm]},
  LabelStyle->Directive[
    GrayLevel[0], FontFamily -> "Helvetica", FontSize -> 14],
  PlotRange->{{0, 1200}, {0, 35}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5644053452929993`*^9, 3.564406084786917*^9}],

Cell[BoxData["\<\"figure2A pt008.eps\"\>"], "Output",
 CellChangeTimes->{3.5644053452929993`*^9, 3.5644060850199404`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "NInput", ",", "PInput", ",", "sink", ",", "f", ",", "r", ",", "m", ",", 
    "k", ",", "q", ",", "\[Alpha]", ",", "Nit", ",", "P", ",", "x", ",", 
    "y"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NInput", "=", ".2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PInput", "=", ".008"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sink", "=", ".01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f", "=", "0.88"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r", "=", ".25"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"m", "=", "10"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"k", "=", "30.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"q", "=", "2.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "=", "0.2"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cp5", "=", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"NInput", "-", 
         RowBox[{"sink", "*", "Nit"}], "+", 
         RowBox[{"f", "*", "P", "*", 
          FractionBox[
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"-", "\[Alpha]"}], "*", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Nit", "/", "P"}], " ", "-", "k"}], ")"}]}]], 
           RowBox[{"1", "+", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"-", "\[Alpha]"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"Nit", "/", "P"}], " ", "-", "k"}], ")"}]}]]}]]}]}], 
        "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"PInput", "-", 
         RowBox[{"sink", "*", "P"}], "+", 
         FractionBox[
          RowBox[{"r", "*", 
           RowBox[{"P", "^", "q"}]}], 
          RowBox[{
           RowBox[{"m", "^", "q"}], "+", 
           RowBox[{"P", "^", "q"}]}]]}], "\[Equal]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Nit", ",", "0", ",", "1200"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"P", ",", "0", ",", "35"}], "}"}], ",", 
     RowBox[{"ContourStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Blue"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Red"}], "}"}]}], 
       "}"}]}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<N\>\"", ",", "\"\<P\>\""}], "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Black", ",", 
        RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "14"}]}], "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot5", "=", 
   RowBox[{"Show", "[", "cp5", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{"\"\<figure2B pt 008.eps\>\"", ",", "%"}], 
  "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.564351280756055*^9, 3.5643513091934853`*^9}, {
   3.564351635248621*^9, 3.5643517021144247`*^9}, 3.56435176640071*^9, {
   3.564351937981619*^9, 3.5643519551163607`*^9}, {3.5644059229199114`*^9, 
   3.5644059485979114`*^9}}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxdmAk0VVsYx5FkKBENCpllSLjIlPuRoTRQZo8oZOaaMkSua57v1SQVeV55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   "], {{}, {}, 
    TagBox[
     TooltipBox[
      {RGBColor[0, 0, 1], Thickness[0.01], 
       LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
         19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 
        36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 
        53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 
        70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 
        87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
        103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 
        117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 
        131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 142, 143, 144, 
        145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 
        159, 160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 
        173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 
        187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197}]},
      RowBox[{
        RowBox[{
          RowBox[{"0.2`", "\[VeryThinSpace]"}], "-", 
          RowBox[{"0.01`", " ", "Nit"}], "+", 
          FractionBox[
           RowBox[{"0.88`", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
                RowBox[{"-", "0.2`"}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"-", "30.`"}], "+", 
                    FractionBox["Nit", "P"]}], ")"}]}]], " ", "P"}], 
           RowBox[{"1", "+", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
                RowBox[{"-", "0.2`"}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"-", "30.`"}], "+", 
                    FractionBox["Nit", "P"]}], ")"}]}]]}]]}], "\[Equal]", 
        "0"}]],
     Annotation[#, 
      0.2 - 0.01 $CellContext`Nit + ((0.88 
          E^((-0.2) (-30. + $CellContext`Nit/$CellContext`P)))/(1 + 
         E^((-0.2) (-30. + $CellContext`Nit/$CellContext`P)))) $CellContext`P == 
      0, "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[1, 0, 0], Thickness[0.01], LineBox[CompressedData["
1:eJwNz1k2QgEAANBXKkRESP21Jee0AQtglzI1UeYxlTESIQr34y7g5lbXV9ZC
QRDk2aDAJltss8MuRUqUqVBlj31q1DngkCOOOeGUM8654JIrrmlwQ5MWbW65
454HHnmiwzMvdHmlxxvv9Pngky8GfPPDkBG//BEIhwgzRoQoMcaZYJI4U0yT
YIZZkswxT4oFFlkizTIZsvwDUr821A==
        "]], LineBox[CompressedData["
1:eJwV0Fc7ggEAQOHP7zCz9whJQyV7S0JmGRmRnfLnvS7e5znXJ1Su5V5agiAo
0SraaKeDTroI0U0PvfTRzwCDDDHMCKOMMc4Ek0wRZpoZZokwR5R5YsRJkGSB
FGkyLJJliWVWWGWNdTbYZIttdthlj31yHJDnkAJHHHNCkVPOOOeCS64oUeaa
G265o8I9DzzyRJVn/qfWeOWNdz745Itv6vzQoMkvf6REHuE=
        "]], LineBox[CompressedData["
1:eJwNxmkyggEAANDPUbqSGRdwgFyAyJJESmkRsmTNlsgu2aJEHcn78WZeaHRs
ODwUBMEI4zJBhEmmiDLNDLPMEWOeOAskWGSJJMukSLNChiyr5MhToMgaJdbZ
YJMyW2yzwy4V9tjngEOOOKbKCaeccc4FNS6pc8U1DW645Y57HnjkiWeavNDi
lTfe+eCTNl9806HLDz1++aPPgH/q/Dl8
        "]]},
      RowBox[{
        RowBox[{
          RowBox[{"0.008`", "\[VeryThinSpace]"}], "-", 
          RowBox[{"0.01`", " ", "P"}], "+", 
          FractionBox[
           RowBox[{"0.25`", " ", 
             SuperscriptBox["P", "2.`"]}], 
           RowBox[{
             RowBox[{"100.`", "\[VeryThinSpace]"}], "+", 
             SuperscriptBox["P", "2.`"]}]]}], "\[Equal]", "0"}]],
     Annotation[#, 
      0.008 - 0.01 $CellContext`P + 
       0.25 ($CellContext`P^2./(100. + $CellContext`P^2.)) == 0, 
      "Tooltip"]& ]}],
  AspectRatio->1,
  Frame->True,
  FrameLabel->{
    FormBox["\"N\"", TraditionalForm], 
    FormBox["\"P\"", TraditionalForm]},
  LabelStyle->Directive[
    GrayLevel[0], FontFamily -> "Helvetica", FontSize -> 14],
  PlotRange->{{0, 1200}, {0, 35}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.564405346586482*^9, 3.564406085271966*^9}],

Cell[BoxData["\<\"figure2B pt 008.eps\"\>"], "Output",
 CellChangeTimes->{3.564405346586482*^9, 3.5644060855089893`*^9}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.564351280756055*^9, 3.5643512840563593`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "NInput", ",", "PInput", ",", "sink", ",", "f", ",", "r", ",", "m", ",", 
    "k", ",", "q", ",", "N", ",", "P", ",", "x", ",", "y"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NInput", "=", ".2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PInput", "=", ".008"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sink", "=", ".01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f", "=", "0.88"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r", "=", ".35"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"m", "=", "10"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"k", "=", "30.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"q", "=", "2.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "=", "0.2"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"cp6", "=", 
    RowBox[{"ContourPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"NInput", "-", 
          RowBox[{"sink", "*", "Nit"}], "+", 
          RowBox[{"f", "*", "P", "*", 
           FractionBox[
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"-", "\[Alpha]"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"Nit", "/", "P"}], " ", "-", "k"}], ")"}]}]], 
            RowBox[{"1", "+", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               RowBox[{"-", "\[Alpha]"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Nit", "/", "P"}], " ", "-", "k"}], ")"}]}]]}]]}]}], 
         "\[Equal]", "0"}], ",", 
        RowBox[{
         RowBox[{"PInput", "-", 
          RowBox[{"sink", "*", "P"}], "+", 
          FractionBox[
           RowBox[{"r", "*", 
            RowBox[{"P", "^", "q"}]}], 
           RowBox[{
            RowBox[{"m", "^", "q"}], "+", 
            RowBox[{"P", "^", "q"}]}]]}], "\[Equal]", "0"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Nit", ",", "0", ",", "1200"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"P", ",", "0", ",", "35"}], "}"}], ",", 
      RowBox[{"ContourStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Blue"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Red"}], "}"}]}], 
        "}"}]}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<N\>\"", ",", "\"\<P\>\""}], "}"}]}], ",", 
      RowBox[{"LabelStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Black", ",", 
         RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
         RowBox[{"FontSize", "\[Rule]", "14"}]}], "]"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot6", "=", 
   RowBox[{"Show", "[", "cp6", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{"\"\<figure2C pt008.eps\>\"", ",", "%"}], "]"}]}], "Input",
 CellChangeTimes->{{3.5643513468411627`*^9, 3.5643513507930107`*^9}, {
  3.564351622929762*^9, 3.5643516278949423`*^9}, {3.5643519590991993`*^9, 
  3.56435196402065*^9}, {3.5644059276549115`*^9, 3.5644059583739114`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Clear", "::", "wrsym"}], "MessageName"], ":", 
  " ", "\<\"Symbol \[NoBreak]\\!\\(N\\)\[NoBreak] is Protected. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/wrsym\\\", \
ButtonNote -> \\\"Clear::wrsym\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5644053469023557`*^9, 3.5644060856330023`*^9}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxdVgk4VekfRrKkv2SpjCW7LAkX2XJfJi2qITsRWRJZrn3Pvma5V1MZZRst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   "], {{}, {}, 
    TagBox[
     TooltipBox[
      {RGBColor[0, 0, 1], Thickness[0.01], 
       LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
         19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 
        36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 
        53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 
        70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 
        87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
        103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 
        117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 
        131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 142, 143, 144, 
        145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 
        159, 160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 
        173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 
        187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197}]},
      RowBox[{
        RowBox[{
          RowBox[{"0.2`", "\[VeryThinSpace]"}], "-", 
          RowBox[{"0.01`", " ", "Nit"}], "+", 
          FractionBox[
           RowBox[{"0.88`", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
                RowBox[{"-", "0.2`"}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"-", "30.`"}], "+", 
                    FractionBox["Nit", "P"]}], ")"}]}]], " ", "P"}], 
           RowBox[{"1", "+", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
                RowBox[{"-", "0.2`"}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"-", "30.`"}], "+", 
                    FractionBox["Nit", "P"]}], ")"}]}]]}]]}], "\[Equal]", 
        "0"}]],
     Annotation[#, 
      0.2 - 0.01 $CellContext`Nit + ((0.88 
          E^((-0.2) (-30. + $CellContext`Nit/$CellContext`P)))/(1 + 
         E^((-0.2) (-30. + $CellContext`Nit/$CellContext`P)))) $CellContext`P == 
      0, "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[1, 0, 0], Thickness[0.01], LineBox[CompressedData["
1:eJwNz1k2QgEAANBXkZCpSAnn2JI/vxbALhvMZc6UkIQQypz7cRdwF5ZXF1dC
QRAskSNPgSJrrLPBJltss0OJMrvssc8BhxxxTIUTTjnjnAuqXFLjimtuqHNL
gzua3PPAIy2eeOaFNq+88U6HLh988sU3P/zyR49AOESYCH30E2WAGIMMMUyc
EUYZY5wJEiSZZIoU06TJMEOWWeaY5x/KUDdO
        "]]},
      RowBox[{
        RowBox[{
          RowBox[{"0.008`", "\[VeryThinSpace]"}], "-", 
          RowBox[{"0.01`", " ", "P"}], "+", 
          FractionBox[
           RowBox[{"0.35`", " ", 
             SuperscriptBox["P", "2.`"]}], 
           RowBox[{
             RowBox[{"100.`", "\[VeryThinSpace]"}], "+", 
             SuperscriptBox["P", "2.`"]}]]}], "\[Equal]", "0"}]],
     Annotation[#, 
      0.008 - 0.01 $CellContext`P + 
       0.35 ($CellContext`P^2./(100. + $CellContext`P^2.)) == 0, 
      "Tooltip"]& ]}],
  AspectRatio->1,
  Frame->True,
  FrameLabel->{
    FormBox["\"N\"", TraditionalForm], 
    FormBox["\"P\"", TraditionalForm]},
  LabelStyle->Directive[
    GrayLevel[0], FontFamily -> "Helvetica", FontSize -> 14],
  PlotRange->{{0, 1200}, {0, 35}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5644053469703283`*^9, 3.5644060856890078`*^9}],

Cell[BoxData["\<\"figure2C pt008.eps\"\>"], "Output",
 CellChangeTimes->{3.5644053469703283`*^9, 3.564406085907029*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "NInput", ",", "PInput", ",", "sink", ",", "f", ",", "r", ",", "m", ",", 
    "k", ",", "q", ",", "N", ",", "P", ",", "x", ",", "y"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NInput", "=", ".2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PInput", "=", ".012"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sink", "=", ".01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f", "=", "0.88"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r", "=", ".15"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"m", "=", "10"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"k", "=", "30.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"q", "=", "2.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "=", "0.2"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"cp7", "=", 
    RowBox[{"ContourPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"NInput", "-", 
          RowBox[{"sink", "*", "Nit"}], "+", 
          RowBox[{"f", "*", "P", "*", 
           FractionBox[
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"-", "\[Alpha]"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"Nit", "/", "P"}], " ", "-", "k"}], ")"}]}]], 
            RowBox[{"1", "+", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               RowBox[{"-", "\[Alpha]"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Nit", "/", "P"}], " ", "-", "k"}], ")"}]}]]}]]}]}], 
         "\[Equal]", "0"}], ",", 
        RowBox[{
         RowBox[{"PInput", "-", 
          RowBox[{"sink", "*", "P"}], "+", 
          FractionBox[
           RowBox[{"r", "*", 
            RowBox[{"P", "^", "q"}]}], 
           RowBox[{
            RowBox[{"m", "^", "q"}], "+", 
            RowBox[{"P", "^", "q"}]}]]}], "\[Equal]", "0"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Nit", ",", "0", ",", "1200"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"P", ",", "0", ",", "35"}], "}"}], ",", 
      RowBox[{"ContourStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Blue"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Red"}], "}"}]}], 
        "}"}]}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<N\>\"", ",", "\"\<P\>\""}], "}"}]}], ",", 
      RowBox[{"LabelStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Black", ",", 
         RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
         RowBox[{"FontSize", "\[Rule]", "14"}]}], "]"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot7", "=", 
   RowBox[{"Show", "[", "cp7", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{"\"\<figure3A pt012.eps\>\"", ",", "%"}], "]"}]}], "Input",
 CellChangeTimes->{{3.564351280756055*^9, 3.5643513383918858`*^9}, {
  3.564351660495411*^9, 3.564351692329215*^9}, {3.564351770552031*^9, 
  3.5643517737433558`*^9}, {3.564351942980723*^9, 3.564351948370141*^9}, {
  3.5644059780199113`*^9, 3.5644060155309114`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Clear", "::", "wrsym"}], "MessageName"], ":", 
  " ", "\<\"Symbol \[NoBreak]\\!\\(N\\)\[NoBreak] is Protected. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/wrsym\\\", \
ButtonNote -> \\\"Clear::wrsym\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.564406085957034*^9}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxdmAk4VWkYx5EsKZUkCtllSZeLbLl/JirVkJ0UQnauPUvZryXLvZr2bKNl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   "], {{}, {}, 
    TagBox[
     TooltipBox[
      {RGBColor[0, 0, 1], Thickness[0.01], 
       LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
         19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 
        36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 
        53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 
        70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 
        87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
        103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 
        117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 
        131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 142, 143, 144, 
        145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 
        159, 160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 
        173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 
        187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197}]},
      RowBox[{
        RowBox[{
          RowBox[{"0.2`", "\[VeryThinSpace]"}], "-", 
          RowBox[{"0.01`", " ", "Nit"}], "+", 
          FractionBox[
           RowBox[{"0.88`", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
                RowBox[{"-", "0.2`"}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"-", "30.`"}], "+", 
                    FractionBox["Nit", "P"]}], ")"}]}]], " ", "P"}], 
           RowBox[{"1", "+", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
                RowBox[{"-", "0.2`"}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"-", "30.`"}], "+", 
                    FractionBox["Nit", "P"]}], ")"}]}]]}]]}], "\[Equal]", 
        "0"}]],
     Annotation[#, 
      0.2 - 0.01 $CellContext`Nit + ((0.88 
          E^((-0.2) (-30. + $CellContext`Nit/$CellContext`P)))/(1 + 
         E^((-0.2) (-30. + $CellContext`Nit/$CellContext`P)))) $CellContext`P == 
      0, "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[1, 0, 0], Thickness[0.01], LineBox[CompressedData["
1:eJwNz2ciggEAANAvexXKJmmo+3SEDpBb2nsnsvfeIvR+vAO8ZGEqXwwFQVBg
mhlmmWOeBRZZYpkVVlljnQ022WKbHXYpsUeZfQ6ocMgRx5xwyhnnXHDJFdfc
cMsd9zzwyBPPvPDKG+988MkXVb75ocYvf/wTCIdooJEmmmmhlTba6aCTLsJE
6KaHXqLE6KOfAQYZYpgRRhkjzjgJJkiSIk2GSbLkqAO4Azib
        "]]},
      RowBox[{
        RowBox[{
          RowBox[{"0.012`", "\[VeryThinSpace]"}], "-", 
          RowBox[{"0.01`", " ", "P"}], "+", 
          FractionBox[
           RowBox[{"0.15`", " ", 
             SuperscriptBox["P", "2.`"]}], 
           RowBox[{
             RowBox[{"100.`", "\[VeryThinSpace]"}], "+", 
             SuperscriptBox["P", "2.`"]}]]}], "\[Equal]", "0"}]],
     Annotation[#, 
      0.012 - 0.01 $CellContext`P + 
       0.15 ($CellContext`P^2./(100. + $CellContext`P^2.)) == 0, 
      "Tooltip"]& ]}],
  AspectRatio->1,
  Frame->True,
  FrameLabel->{
    FormBox["\"N\"", TraditionalForm], 
    FormBox["\"P\"", TraditionalForm]},
  LabelStyle->Directive[
    GrayLevel[0], FontFamily -> "Helvetica", FontSize -> 14],
  PlotRange->{{0, 1200}, {0, 35}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5644060860630445`*^9}],

Cell[BoxData["\<\"figure3A pt012.eps\"\>"], "Output",
 CellChangeTimes->{3.5644060862580643`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "NInput", ",", "PInput", ",", "sink", ",", "f", ",", "r", ",", "m", ",", 
    "k", ",", "q", ",", "N", ",", "P", ",", "x", ",", "y"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NInput", "=", ".2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PInput", "=", ".012"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sink", "=", ".01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f", "=", "0.88"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r", "=", ".25"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"m", "=", "10"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"k", "=", "30.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"q", "=", "2.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "=", "0.2"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"cp8", "=", 
    RowBox[{"ContourPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"NInput", "-", 
          RowBox[{"sink", "*", "Nit"}], "+", 
          RowBox[{"f", "*", "P", "*", 
           FractionBox[
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"-", "\[Alpha]"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"Nit", "/", "P"}], " ", "-", "k"}], ")"}]}]], 
            RowBox[{"1", "+", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               RowBox[{"-", "\[Alpha]"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Nit", "/", "P"}], " ", "-", "k"}], ")"}]}]]}]]}]}], 
         "\[Equal]", "0"}], ",", 
        RowBox[{
         RowBox[{"PInput", "-", 
          RowBox[{"sink", "*", "P"}], "+", 
          FractionBox[
           RowBox[{"r", "*", 
            RowBox[{"P", "^", "q"}]}], 
           RowBox[{
            RowBox[{"m", "^", "q"}], "+", 
            RowBox[{"P", "^", "q"}]}]]}], "\[Equal]", "0"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Nit", ",", "0", ",", "1200"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"P", ",", "0", ",", "35"}], "}"}], ",", 
      RowBox[{"ContourStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Blue"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Red"}], "}"}]}], 
        "}"}]}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<N\>\"", ",", "\"\<P\>\""}], "}"}]}], ",", 
      RowBox[{"LabelStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Black", ",", 
         RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
         RowBox[{"FontSize", "\[Rule]", "14"}]}], "]"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot8", "=", 
   RowBox[{"Show", "[", "cp8", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{"\"\<figure3B pt012.eps\>\"", ",", "%"}], "]"}]}], "Input",
 CellChangeTimes->{{3.564351280756055*^9, 3.5643513383918858`*^9}, {
  3.564351660495411*^9, 3.564351692329215*^9}, {3.564351770552031*^9, 
  3.5643517737433558`*^9}, {3.564351942980723*^9, 3.564351948370141*^9}, {
  3.5644059833739114`*^9, 3.564405986640911*^9}, {3.5644060196629114`*^9, 
  3.5644060348409114`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Clear", "::", "wrsym"}], "MessageName"], ":", 
  " ", "\<\"Symbol \[NoBreak]\\!\\(N\\)\[NoBreak] is Protected. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/wrsym\\\", \
ButtonNote -> \\\"Clear::wrsym\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5644060864470835`*^9}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxdlgk4lekbxpEsaSSkxb4vSTjIlnMzoZSh7IaSJTtHtsh67OJwtEnZxpSp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   "], {{}, {}, 
    TagBox[
     TooltipBox[
      {RGBColor[0, 0, 1], Thickness[0.01], 
       LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
         19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 
        36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 
        53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 
        70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 
        87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
        103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 
        117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 
        131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 142, 143, 144, 
        145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 
        159, 160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 
        173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 
        187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197}]},
      RowBox[{
        RowBox[{
          RowBox[{"0.2`", "\[VeryThinSpace]"}], "-", 
          RowBox[{"0.01`", " ", "Nit"}], "+", 
          FractionBox[
           RowBox[{"0.88`", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
                RowBox[{"-", "0.2`"}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"-", "30.`"}], "+", 
                    FractionBox["Nit", "P"]}], ")"}]}]], " ", "P"}], 
           RowBox[{"1", "+", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
                RowBox[{"-", "0.2`"}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"-", "30.`"}], "+", 
                    FractionBox["Nit", "P"]}], ")"}]}]]}]]}], "\[Equal]", 
        "0"}]],
     Annotation[#, 
      0.2 - 0.01 $CellContext`Nit + ((0.88 
          E^((-0.2) (-30. + $CellContext`Nit/$CellContext`P)))/(1 + 
         E^((-0.2) (-30. + $CellContext`Nit/$CellContext`P)))) $CellContext`P == 
      0, "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[1, 0, 0], Thickness[0.01], LineBox[CompressedData["
1:eJwNz1k2QgEAANBXKkRESP21Jee0AQtglzI1UeYxlTESIQr34y7g5lbXV9ZC
QRDk2aDAJltss8MuRUqUqVBlj31q1DngkCOOOeGUM8654JIrrmlwQ5MWbW65
454HHnmiwzMvdHmlxxvv9Pngky8GfPPDkBG//BEIhwgzRoQoMcaZYJI4U0yT
YIZZkswxT4oFFlkizTIZsvwDUr821A==
        "]]},
      RowBox[{
        RowBox[{
          RowBox[{"0.012`", "\[VeryThinSpace]"}], "-", 
          RowBox[{"0.01`", " ", "P"}], "+", 
          FractionBox[
           RowBox[{"0.25`", " ", 
             SuperscriptBox["P", "2.`"]}], 
           RowBox[{
             RowBox[{"100.`", "\[VeryThinSpace]"}], "+", 
             SuperscriptBox["P", "2.`"]}]]}], "\[Equal]", "0"}]],
     Annotation[#, 
      0.012 - 0.01 $CellContext`P + 
       0.25 ($CellContext`P^2./(100. + $CellContext`P^2.)) == 0, 
      "Tooltip"]& ]}],
  AspectRatio->1,
  Frame->True,
  FrameLabel->{
    FormBox["\"N\"", TraditionalForm], 
    FormBox["\"P\"", TraditionalForm]},
  LabelStyle->Directive[
    GrayLevel[0], FontFamily -> "Helvetica", FontSize -> 14],
  PlotRange->{{0, 1200}, {0, 35}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5644060865480933`*^9}],

Cell[BoxData["\<\"figure3B pt012.eps\"\>"], "Output",
 CellChangeTimes->{3.564406086725111*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "NInput", ",", "PInput", ",", "sink", ",", "f", ",", "r", ",", "m", ",", 
    "k", ",", "q", ",", "N", ",", "P", ",", "x", ",", "y"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NInput", "=", ".2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PInput", "=", ".012"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sink", "=", ".01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f", "=", "0.88"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r", "=", ".35"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"m", "=", "10"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"k", "=", "30.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"q", "=", "2.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "=", "0.2"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"cp9", "=", 
    RowBox[{"ContourPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"NInput", "-", 
          RowBox[{"sink", "*", "Nit"}], "+", 
          RowBox[{"f", "*", "P", "*", 
           FractionBox[
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"-", "\[Alpha]"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"Nit", "/", "P"}], " ", "-", "k"}], ")"}]}]], 
            RowBox[{"1", "+", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               RowBox[{"-", "\[Alpha]"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Nit", "/", "P"}], " ", "-", "k"}], ")"}]}]]}]]}]}], 
         "\[Equal]", "0"}], ",", 
        RowBox[{
         RowBox[{"PInput", "-", 
          RowBox[{"sink", "*", "P"}], "+", 
          FractionBox[
           RowBox[{"r", "*", 
            RowBox[{"P", "^", "q"}]}], 
           RowBox[{
            RowBox[{"m", "^", "q"}], "+", 
            RowBox[{"P", "^", "q"}]}]]}], "\[Equal]", "0"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Nit", ",", "0", ",", "1200"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"P", ",", "0", ",", "35"}], "}"}], ",", 
      RowBox[{"ContourStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Blue"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Red"}], "}"}]}], 
        "}"}]}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<N\>\"", ",", "\"\<P\>\""}], "}"}]}], ",", 
      RowBox[{"LabelStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Black", ",", 
         RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
         RowBox[{"FontSize", "\[Rule]", "14"}]}], "]"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot9", "=", 
   RowBox[{"Show", "[", "cp9", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{"\"\<figure3C pt012.eps\>\"", ",", "%"}], "]"}]}], "Input",
 CellChangeTimes->{{3.564351280756055*^9, 3.5643513383918858`*^9}, {
  3.564351660495411*^9, 3.564351692329215*^9}, {3.564351770552031*^9, 
  3.5643517737433558`*^9}, {3.564351942980723*^9, 3.564351948370141*^9}, {
  3.5644059923379116`*^9, 3.5644059950959115`*^9}, {3.564406039593911*^9, 
  3.5644060558409114`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Clear", "::", "wrsym"}], "MessageName"], ":", 
  " ", "\<\"Symbol \[NoBreak]\\!\\(N\\)\[NoBreak] is Protected. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/wrsym\\\", \
ButtonNote -> \\\"Clear::wrsym\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.564406086859124*^9}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxdmAk0VesbxpFkKGVoFClT5uEgU+c8FEm5yBCuQsg8ZSgyHrNMR5Mr4xVu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   "], {{}, {}, 
    TagBox[
     TooltipBox[
      {RGBColor[0, 0, 1], Thickness[0.01], 
       LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
         19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 
        36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 
        53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 
        70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 
        87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
        103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 
        117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 
        131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 142, 143, 144, 
        145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 
        159, 160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 
        173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 
        187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197}]},
      RowBox[{
        RowBox[{
          RowBox[{"0.2`", "\[VeryThinSpace]"}], "-", 
          RowBox[{"0.01`", " ", "Nit"}], "+", 
          FractionBox[
           RowBox[{"0.88`", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
                RowBox[{"-", "0.2`"}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"-", "30.`"}], "+", 
                    FractionBox["Nit", "P"]}], ")"}]}]], " ", "P"}], 
           RowBox[{"1", "+", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
                RowBox[{"-", "0.2`"}], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"-", "30.`"}], "+", 
                    FractionBox["Nit", "P"]}], ")"}]}]]}]]}], "\[Equal]", 
        "0"}]],
     Annotation[#, 
      0.2 - 0.01 $CellContext`Nit + ((0.88 
          E^((-0.2) (-30. + $CellContext`Nit/$CellContext`P)))/(1 + 
         E^((-0.2) (-30. + $CellContext`Nit/$CellContext`P)))) $CellContext`P == 
      0, "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[1, 0, 0], Thickness[0.01], LineBox[CompressedData["
1:eJwNz2ciggEAANAvexXKJmmo+3SEDpBb2nsnsvfeIvR+vAO8ZGEqXwwFQVBg
mhlmmWOeBRZZYpkVVlljnQ022WKbHXYpsUeZfQ6ocMgRx5xwyhnnXHDJFdfc
cMsd9zzwyBPPvPDKG+988MkXVb75ocYvf/wTCIdooJEmmmmhlTba6aCTLsJE
6KaHXqLE6KOfAQYZYpgRRhkjzjgJJkiSIk2GSbLkqAO4Azib
        "]]},
      RowBox[{
        RowBox[{
          RowBox[{"0.012`", "\[VeryThinSpace]"}], "-", 
          RowBox[{"0.01`", " ", "P"}], "+", 
          FractionBox[
           RowBox[{"0.35`", " ", 
             SuperscriptBox["P", "2.`"]}], 
           RowBox[{
             RowBox[{"100.`", "\[VeryThinSpace]"}], "+", 
             SuperscriptBox["P", "2.`"]}]]}], "\[Equal]", "0"}]],
     Annotation[#, 
      0.012 - 0.01 $CellContext`P + 
       0.35 ($CellContext`P^2./(100. + $CellContext`P^2.)) == 0, 
      "Tooltip"]& ]}],
  AspectRatio->1,
  Frame->True,
  FrameLabel->{
    FormBox["\"N\"", TraditionalForm], 
    FormBox["\"P\"", TraditionalForm]},
  LabelStyle->Directive[
    GrayLevel[0], FontFamily -> "Helvetica", FontSize -> 14],
  PlotRange->{{0, 1200}, {0, 35}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5644060868621244`*^9}],

Cell[BoxData["\<\"figure3C pt012.eps\"\>"], "Output",
 CellChangeTimes->{3.5644060870631447`*^9}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.5643513468411627`*^9, 3.5643513507930107`*^9}}],

Cell[TextData[StyleBox["Below we combine the nine images into a single grid \
for inclusion in the article.",
 Background->RGBColor[0.9, 1, 1]]], "Text",
 CellChangeTimes->{{3.610271043974658*^9, 3.6102710862540765`*^9}, {
  3.6223886424589643`*^9, 3.622388720439076*^9}, {3.622388795766714*^9, 
  3.622388983486995*^9}, {3.6223890290170603`*^9, 3.622389045727086*^9}, {
  3.622389104609673*^9, 3.6223891181496925`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"GraphicsGrid", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"plot1", ",", "plot2", ",", "plot3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"plot4", ",", "plot5", ",", "plot6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"plot7", ",", "plot8", ",", "plot9"}], "}"}]}], "}"}], "]"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.564351362201788*^9, 3.5643513667104273`*^9}, {
   3.564351525646542*^9, 3.564351526910233*^9}, {3.5643517090975847`*^9, 
   3.564351719248898*^9}, 3.564351824273741*^9, {3.5644055014469113`*^9, 
   3.5644055167549114`*^9}, {3.564405600152911*^9, 3.5644056041659117`*^9}, {
   3.5644060638929114`*^9, 3.5644060807085094`*^9}}],

Cell[CellGroupData[{

Cell["", "Section"],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxdlwk41dkbx5FC+itLq+y7KFxky/0yoUjIbm5pITvXWvZrX7Lcq10RY2mm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        "], {{}, {}, 
         TagBox[
          TooltipBox[
           {RGBColor[0, 0, 1], Thickness[0.01], 
            LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 
             17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 
             33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 
             49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 
             65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 
             81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 
             97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 
             110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 
             123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 
             136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 
             149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 
             162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 
             175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 
             188, 189, 190, 191, 192, 193, 194, 195, 196, 197}]},
           RowBox[{
             RowBox[{
               RowBox[{"0.2`", "\[VeryThinSpace]"}], "-", 
               RowBox[{"0.01`", " ", "Nit"}], "+", 
               FractionBox[
                RowBox[{"0.88`", " ", 
                  SuperscriptBox["\[ExponentialE]", 
                   RowBox[{
                    RowBox[{"-", "0.2`"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "30.`"}], "+", 
                    FractionBox["Nit", "P"]}], ")"}]}]], " ", "P"}], 
                RowBox[{"1", "+", 
                  SuperscriptBox["\[ExponentialE]", 
                   RowBox[{
                    RowBox[{"-", "0.2`"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "30.`"}], "+", 
                    FractionBox["Nit", "P"]}], ")"}]}]]}]]}], "\[Equal]", 
             "0"}]],
          
          Annotation[#, 
           0.2 - 0.01 $CellContext`Nit + ((0.88 
               E^((-0.2) (-30. + $CellContext`Nit/$CellContext`P)))/(1 + 
              E^((-0.2) (-30. + $CellContext`Nit/$CellContext`P)))) \
$CellContext`P == 0, "Tooltip"]& ], 
         TagBox[
          TooltipBox[
           {RGBColor[1, 0, 0], Thickness[0.01], LineBox[CompressedData["
1:eJwNz0VWQgEAAMCPii1iB0qZeByP4Htu9ZY22IHd3YitMIs5wKQmpsenQkEQ
TDLDLHPMs8AiS2TJscwKq6yxzgabbLHNDnl22WOfAw454pgTTjnjnAsuueKa
G265454HHnnimRdeKfBGkXc++OSLb3745Y9/SgTCISqopIow1dRQSx31NNBI
ExGaidJCK22000EnXXTTQy8x+ugnToIkKdIMMMgQw4wwSoYxymghORw=
             "]]},
           RowBox[{
             RowBox[{
               RowBox[{"0.004`", "\[VeryThinSpace]"}], "-", 
               RowBox[{"0.01`", " ", "P"}], "+", 
               FractionBox[
                RowBox[{"0.15`", " ", 
                  SuperscriptBox["P", "2.`"]}], 
                RowBox[{
                  RowBox[{"100.`", "\[VeryThinSpace]"}], "+", 
                  SuperscriptBox["P", "2.`"]}]]}], "\[Equal]", "0"}]],
          
          Annotation[#, 
           0.004 - 0.01 $CellContext`P + 
            0.15 ($CellContext`P^2./(100. + $CellContext`P^2.)) == 0, 
           "Tooltip"]& ]}],
       AspectRatio->1,
       Frame->True,
       FrameLabel->{
         FormBox["\"N\"", TraditionalForm], 
         FormBox["\"P\"", TraditionalForm]},
       LabelStyle->Directive[
         GrayLevel[0], FontFamily -> "Helvetica", FontSize -> 14],
       PlotRange->{{0, 1200}, {0, 35}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {193.5, -193.5}, 
      ImageScaled[{0.5, 0.5}], {360., 360.}], InsetBox[
      GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxdmAk0lO0bxpFC+iuSkmzZl0qGsmVuvmQpkX2NLFmHsWcf29iZ0deeIu1F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        "], {{}, {}, 
         TagBox[
          TooltipBox[
           {RGBColor[0, 0, 1], Thickness[0.01], 
            LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 
             17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 
             33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 
             49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 
             65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 
             81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 
             97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 
             110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 
             123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 
             136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 
             149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 
             162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 
             175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 
             188, 189, 190, 191, 192, 193, 194, 195, 196, 197}]},
           RowBox[{
             RowBox[{
               RowBox[{"0.2`", "\[VeryThinSpace]"}], "-", 
               RowBox[{"0.01`", " ", "Nit"}], "+", 
               FractionBox[
                RowBox[{"0.88`", " ", 
                  SuperscriptBox["\[ExponentialE]", 
                   RowBox[{
                    RowBox[{"-", "0.2`"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "30.`"}], "+", 
                    FractionBox["Nit", "P"]}], ")"}]}]], " ", "P"}], 
                RowBox[{"1", "+", 
                  SuperscriptBox["\[ExponentialE]", 
                   RowBox[{
                    RowBox[{"-", "0.2`"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "30.`"}], "+", 
                    FractionBox["Nit", "P"]}], ")"}]}]]}]]}], "\[Equal]", 
             "0"}]],
          
          Annotation[#, 
           0.2 - 0.01 $CellContext`Nit + ((0.88 
               E^((-0.2) (-30. + $CellContext`Nit/$CellContext`P)))/(1 + 
              E^((-0.2) (-30. + $CellContext`Nit/$CellContext`P)))) \
$CellContext`P == 0, "Tooltip"]& ], 
         TagBox[
          TooltipBox[
           {RGBColor[1, 0, 0], Thickness[0.01], LineBox[CompressedData["
1:eJwNz1k2QgEAANBXKkRESP21Jee0AQtglzI1UeYxlTESIQr34y7g5lbXV9ZC
QRDk2aDAJltss8MuRUqUqVBlj31q1DngkCOOOeGUM8654JIrrmlwQ5MWbW65
454HHnmiwzMvdHmlxxvv9Pngky8GfPPDkBG//BEIhwgzRoQoMcaZYJI4U0yT
YIZZkswxT4oFFlkizTIZsvwDUr821A==
             "]], LineBox[CompressedData["
1:eJwV0Nk2QgEAQNHbd4QkypSMSYOQoYhIoTKVyNDw/292D3ut83yivUl9HAqC
oElYzDDLHBHmibJAjEWWiJNgmRVWWWOdJBuk2GSLbXbYZY80+2Q4IEuOPAUO
KXLEMSeUOOWMcy4oU+GSK6pcc0ONW+6oc0+DJg888kSLNh2eeeGVN97p0uOD
Pp98MeCbH375Y8iI6dQJ/0YlGUc=
             "]], LineBox[CompressedData["
1:eJwNxlVSQgEAAMDnUbySR3DGX7EFO8FCEewOLBTF7u5G5UDux85scWmopLwo
CIIyKqSSKqqpoZY66gkToYFGmmimhVbaaKeDTrroJkqMHnrpo58B4gwyRIJh
kqQYYZQxxplgkimmmWGWOeZZYJEllkmzwiprrLNBhk22yLLNDjl22WOfAw45
4pgTTjnjnAsuueKaG265454HHnnimRdeeeOdDz754ps8P/zyR4F/Zz9CaA==

             "]]},
           RowBox[{
             RowBox[{
               RowBox[{"0.004`", "\[VeryThinSpace]"}], "-", 
               RowBox[{"0.01`", " ", "P"}], "+", 
               FractionBox[
                RowBox[{"0.25`", " ", 
                  SuperscriptBox["P", "2.`"]}], 
                RowBox[{
                  RowBox[{"100.`", "\[VeryThinSpace]"}], "+", 
                  SuperscriptBox["P", "2.`"]}]]}], "\[Equal]", "0"}]],
          
          Annotation[#, 
           0.004 - 0.01 $CellContext`P + 
            0.25 ($CellContext`P^2./(100. + $CellContext`P^2.)) == 0, 
           "Tooltip"]& ]}],
       AspectRatio->1,
       Frame->True,
       FrameLabel->{
         FormBox["\"N\"", TraditionalForm], 
         FormBox["\"P\"", TraditionalForm]},
       LabelStyle->Directive[
         GrayLevel[0], FontFamily -> "Helvetica", FontSize -> 14],
       PlotRange->{{0, 1200}, {0, 35}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {580.5, -193.5}, 
      ImageScaled[{0.5, 0.5}], {360., 360.}], InsetBox[
      GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxdmAk4lF0bx23ZPyRaJdmTQoNsmZsiSS9liUKI7Pu+MxhLY8zQIoW8ilJK
izZ6U6J6wytLogUpCilpo9JnzHOe52Iu1+X6ue/zf875n3Pf5zGr3QJ3eXBx
cHA85eTgYP3ueGuzxp9LEzhmP2HkS1l5uxMuaoIl132ThXuLyTR16+7oIk0w
TNEwe0ZpID+/5j/zowV3eF9TJfQfkZXGFucLKOiCSOTDdcsy+shCf3udSaDo
Y3pvyPLbcuW3iQNY9VTqLn/4jlyr4+lUZWQEJdLCN04/GiFPBby2M19jjOWP
YfomkMRsX3DZ8jP5V2PJR4GzprDVtDL8cvdncoud0pKbwVux/C/kp1QRxsa8
7TDxV+ttj80/yCKtJPGuJ9ux+CT2fCtQh1/mV3f+JpsatHGtM7QCJT1ZV/EL
v8muNtbC3h5WWP40efZX3S6gfC6pEbTnBJUWVfVdHbsgZf3TYn5/Tgi8XNXd
MLiLnZ/ECXcuqQTLydjAprh1++2uc4H551XfvpBtoYXWzbe9kxtq+d8yin1t
MX0emFTOXXbKzxYuPawI4uDkAfZ6beHVHaFuES4eCMg1L/WvsQObyMcFGWYL
YJw5+bJpcjf2PF5YW1Q0qCJoD5Z723SlGLwwO3yFPQzFdp9YWsILBpnX+YrS
92DPE4C0b5Yenmf2wPXBTQF0aQHIZRnyaA9Mvb9ZFA0C8Nav+NpKSSdMXwjM
TAsddUydwK7yzbR7pRCw5J9HOIEVX91uxT4h0FyZGbj7732YvgjYMarzPg7s
A7Nok3xrAxFg++0CWxNHXi9KEoEvzBXdFUtc2fkgBhPtlR/vgytIrbl/9IKH
GHs+3q6wKVjLUYohBs0/jtSJObth81kIIjt/JKbkuEHrWj4Oo8qF7L/XuUEt
yd3x24uFYG0+IK75aj8k5Q9F9H0RB5u7alw2H92x+UnAfheuQ12qHnDViipD
M5DA/PaAKtGAZPc4Cag5PSkcGHsAHr74wrM5VRLSDanP6+I8secvBn7pnMyf
jzxhh+5WFZ6mxZjfXtAleItfRWoJVHw5KpCw1Bumgq6VtCxaCv94NH3vEfDB
nr8MSoTiY74f8IFCv8rskr3LMP99YJP+xEGd2mUQ8uT1Va9qX9i/fFIurnQ5
NJ+oO3LpiB/2/BXQFZ4e18btDz4/hiqdRlZg++EP7WNC9BRHKVgwZpystSsA
ulfvTTchrYSwjAClnXKB2POlYfX5bJfck4FwotRhJSlWGtufILhjO1zP8Vsa
zD8ebw+LDIL8tIhRhfpV8I3T6EF/VxC2XzLQoMd8XygdDBOHC+7Q02Sw/QqG
Et67I+0tMvCnL6jifkMwyFkZXaOtWQ1ihzdY8UuHYPNfDSs3FJu99wsBhqLS
OVrzamz/QoASfYtPd5UsTILZuJBEKOR8kw2jB8uC+Y/n21a5h2J5spB9fKpJ
tSYU7jrtGWFKykHZmPSwIHcYO+4iBwEsPxaHgfaq9tqQUDngqQpzsHMJg574
STnfGjlQK0/mdizD8jnk2eu/FwbGbSvLvVbIwwYxB/0CvnAY+HR7eMc+eQh6
puBTvi2cnX9SHjsv4aATK8HrXi8PCke9LJ9fCIcacpwliVsBxJ2/BX4YxfJB
ge3PsghQCaDnuPsqQMP0aO/J3RFwp+DjygunFaDU5KrbekYEO79PAcxYA+5H
gGTZv7+8FylCIbX0+K3pCHCkZOrf2KYIZhu7DvqQIjE/FeEP6xMYCfxcBYJh
NYowQjqp3X46ErwqCw/Uf1CEfvMc9b+fYvkySth5jQLDEp9oyn4leHnn+/1h
iyi4tSyA9h9TCa6IvWR2Rkdhfiuxz1djFJAkDP93WEgZMh5+s+f8EgUCUYPH
X2gps/0LiYaHhkP1w5eUISjxeu2nu9GYv2tAOcmqfa1xDDwaa9CbjF+DnfcY
kJ9WbaRzqUC29fhT8vsYaEvoucAvqwLrPcmNrXyxmH8q0GgtvMKaEQv2elWd
SxtVsHXEQXPjZ05d67WgdGNd0LkdcZgfa4Fe8CM38lUcFO7wF9MXUcXqIx6o
21tq3pWqwrPcOufkvHhsfaqwePgx/ZhqApRvfX5in9066GEZ1JwAJHVDm8Iv
6yD6tc1K6+4EbD3roTei3/ZmTCLAfRcdatF68DE5FaN5PRF+h9ZcG+1eD+JN
uvtviSZh81fD6isJeEff/rvARA2iazsTS9yTIPTNXxzmg2qQdjVt7aorKF+d
fb5uJ4Fb4U/HA+bq0OxB+TwmlAypa9y7p4+og+g0p0C8XTJ2XtSx+kuGrT0D
Nlaf1eHFpDKH7pVksCm+/vK5ngacPall0TGJ5SdpsM+XBAWGux3ToUADdvz4
rzVxDwUO+zcO1byayR+X2aZQSMF83sA+X3coILr2a4W28QY4kpaeXc+ZAsLk
TU+KKBuAnmRpEwQpmJ8b2OfLNwWmKCrhG4Y3QIOQ8T6esylAi38TmqpIgpG2
kbrqASzfhQR+s/WaCiInFU6Qcknw5urCAGOrVLjca1vh9y8JBv9J7f1KTcX8
1wS52XpNhdCJ3i5dPU04Lnm+L/57KjiGBVntDtCEV2o7fqurpGH1qsneT/80
cCnrfb3ltSbkX5B+ca0oDR4sLd68RVwLrkhV7fdsxvJBC5iz9UqFTPezMTZZ
WmC583TKBxMqVO/440a6pgUOi6XtjwVRMf+1sHqlAlNlep/XBm2IGTj6Y/UH
KtQZhOTI79GGg92cUg8WpWP+a8P0bL2mw+7hL3ZJPdpwT8Jrj82hdMh+XnRu
ybQ26Pa1jH66huXLbITq2XrNgB6Ln4onKBtBeKD0tqlBBjwZ2pK3u2QjjLbL
8CzZk4H5v5HtZ2MGWJ9sKKhR0YEgfrKP/UAG/OoM1PY20QHZ2XrNBLJ0mGLn
Ex0oUyK5eGdlQnmaRGrsex2YBuc3riWZmN+6MCU8eC5aIwsu1J0MomfrAmO2
frOgLSYpI0tWDxRI5faZz7KAKkEdL9HQg4BjW0U0hrIwP/XggWVzUH7iQVho
KP27ulOPvf5VNCBVOLRvCdWHNfqtv8sUaTD1Mzfr32h9SFTfJ/NLlYb5pQ+c
1fv4q5tpkNbykNm70gAEFx6srJXPBrLHivt7Qg3gXU664YLQbGz9BhB9mr9j
ICwbeF4O8j69awC+s/WfDdmePIz79Qago3jNQkuKDiPhzdLnPTbBqKkaveMm
HVuvIZRrJP1JrafDT0XbVykChvBsth/Q4eJi9XTqIkOgCb4fb/PJgf5LDuBU
aQgL7kWMmXMwsPWSQXy13WFRAQZ88Ms11NlJZp9XcQZorVjEtN1PhqzE2mdX
HRmwzq79icRXMoxmmj85VYrGA5wzctzqUMWAvxxXR0dbAPv83maA39CRU/kO
AAaeF9/+4mbCtap7272LgF1vi5jgayj/dKgSgKfsTyTdlImdT5jxzfVG8W4m
pKQEv3D4BOzz7c0EjSjHFx84jWDnepmONflYvroRlGYc2s53jgm2zuE3k42N
2OfpHyYMBGkEk+yM4En31K5LdVi+vREor78k0tnBhJX8d73jfY3AckS/o/49
Fk8ywvYlF55z5dnRY3ig4hVJ8PF1gouufDJ8IEUwuz/lAr3R/ONdLx74HGRv
7SRMxIdMJDMcgpk4o/Ug1ueOP/HRhWD1Z7pPRhoYOCM/kX7q4ZK3ydVEPNrH
eXnCcoLR/iFuVmpcLyFIcMrkggcyr+g4o/OC9NeFdX60uE3EF0tbOpikZ+OM
zifiunxpSvABgs8a5494q9NwRvWD9K1ve0ocESXi+p798fTuLJxRvSJ+219V
dusGwc0HVcSuUDJxRv0B6UfyTun0uhJxl6rQv7vWZuCM+hNiwbWbH3MLETzR
Uav5q4M6d39n+iXSL7SkOSlfJeJpLD8T0ubulz/Baiw/nQhewvJTKRVndJ8g
/bssP3mJeAXLz1YKzuh+Q2zD8vMiwZtYfkYn44zuW6Q/xPLTnoj/x/JTNgln
dP/j54vlJyfB9S5DWy4ejccZva8g/SV21CN8dkT83dlo7x8z70tz5vOIYIPi
pTVWZwgWnhCiGxlE4Yze/5C+y7uK3mNTkXhcw6DochY9HGf0vovvj8YmngEL
gu3S1Lva+0JwZtd7CK5fEfOfsmoxEY9pufdTihQ0zx+CT6TXFwy/DsTZUK0C
mgR9563XB9cfXPZuIC7dB4+n323JdL7oMW/+BKudF14nqkpwq/VE2ydrl3nz
ccH1P8a5jRqX7MPjmk1qOrzjtvP0CaaUnEvwHLbBmdY/fsg2zHRevgmur0J7
v3qp5xaiP5xjHVCOuX7OfOazKd8HgR2qAIkjb3VUV0gCYt9JK5ud/xrjjJ73
eRVHmvoMbw/LcpNaaIbH0fchiOXse5fwSNnMG2+Lc57kryLvO3Y4M0hH0nrb
nOfpueDPS4pyoMrWuODxxPSy6Jf33efpe+C8cVBzE2PxAZy1vyarb5fxwRnt
P9Ifsxb78jvYF4+PujkN3YgNnDefIJzb+sI7qw8QvMtLyjLPNwRndH6R/oWj
A1V+M/+Povi6VVkq5svC582f4My/dtLk7hHM//T7As4HkTij+kP67gvuePYE
RuHxNzSP/uthMfPWSzDUqm5mrozF+c7m9toA2XicUf9A+itCC6TNHhPxginI
V2hNnOdPEs4/JXjiEw0IrrHv0h0zTJ47n5n+h/S9P90a3pNHxJU16eWPDlNw
Rv0V8dPHwfbawwQfFjWRPD2agjPq30h/c7ly40KjVDzOPfKTkrQ5DWd0PyC+
ROklfThKcHDj5U97C6g4o/sH6a9yPlLycIyIvyrxdt44no4zut8Q03R3iJ4y
IXh7vEyTuFkmzuj+RPqTLD9PEPGbLD+Lsoj6we5nxJ4sPycIVmL5+fUgzuj+
R/qdLD/NaXj8EMtPi2yiH2DvF4iNWX6WEMzJ8rOUjjN6f0H6F1l+fifigSw/
p3KIfoG9HyEWUXts5a5E8Fir5sXjZxhz92vm/QvpN54o42trI+JlhmIHBGyY
OKP3O8RxgpR/yAkEO54fkYr8w5y7vzPvj0hfM8opvHJN7tzz7kOwxPIH7W8q
CEbvq3N45iNiOZ3nktNLPmYXPDQkKQ6ItVyZ/Qbv1HFG34cjThY271Sf0MWZ
n5b4alJl87x8E5wv9O99Flq1FedwT22Lzv4dOKN+jZjuLFBaTtqJc0jJN0d7
C5t5+raQvnHa+LZTH3lL0xsHyRw7PK4s2raosdwBZ/R9MMq/bLu7b+e9vTij
/v7Q86VLVtwgOWjoh733Zjc8zljKV37EYD/OqL8jVrTtEO0q8sTZlPraiSff
C2fU35H+y3sXG7dM+eHx3xO3JUIm/OfNJwhn8/wGw26VYJx7qpreBpYTjPo7
0le0JC1nPAvF49c89e4q2obNm384MZ635KspNYJYr/SZEy+5IonxWH9H+i9q
RZ78JkXjcb9OyahDVdHz1huD843QuPNX+2NxNqOlWG93jsMZ9Xekn6synO6b
k4DHZTePr+cSTpznTxLO1z+d02AWEfwnTi3txYukufOZ6e9IX77JrdjvazIx
f/vBz9dJFGI81t/x8eXL/mdmkUL4Typ0ycsiGPV3pP+H0hojV5qKx7eK2rQE
9BOM+ju+fuf0d9OTBFcPCxqY61AJv7D+jvR7dA3teqzSCX8a755VyCEY9Xd8
vOTX+upyghklUUs4BwlG/R3pV7P8nM4kzifLT4MsYjzW3xHLsfy0PYizL8vP
PIJRf0f6DJaf52l4/BnLz2GCUX/Hx7P85KYT9cXy04hg1N+Rvi/LT4ccPH6F
5Wc+wai/Ix6VWrXW355gsYG+jtxIxtz9munvSP9U1lR/Dzdzbn0sIvh/vfeK
UhSYeP/Rv+JaIbKbYNT/Uf7QYfUYvVgiLunzX1rDeYLR9xWI6y2KbMdbCR6X
2eQax5WLM7ovEBdzC2ucUSS4uavCgGSfO7f/+hAceytaeF8cwWfpS5cOVxKM
7hPE/weyWUxV
        "], {{}, {}, 
         TagBox[
          TooltipBox[
           {RGBColor[0, 0, 1], Thickness[0.01], 
            LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 
             17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 
             33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 
             49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 
             65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 
             81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 
             97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 
             110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 
             123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 
             136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 
             149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 
             162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 
             175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 
             188, 189, 190, 191, 192, 193, 194, 195, 196, 197}]},
           RowBox[{
             RowBox[{
               RowBox[{"0.2`", "\[VeryThinSpace]"}], "-", 
               RowBox[{"0.01`", " ", "Nit"}], "+", 
               FractionBox[
                RowBox[{"0.88`", " ", 
                  SuperscriptBox["\[ExponentialE]", 
                   RowBox[{
                    RowBox[{"-", "0.2`"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "30.`"}], "+", 
                    FractionBox["Nit", "P"]}], ")"}]}]], " ", "P"}], 
                RowBox[{"1", "+", 
                  SuperscriptBox["\[ExponentialE]", 
                   RowBox[{
                    RowBox[{"-", "0.2`"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "30.`"}], "+", 
                    FractionBox["Nit", "P"]}], ")"}]}]]}]]}], "\[Equal]", 
             "0"}]],
          
          Annotation[#, 
           0.2 - 0.01 $CellContext`Nit + ((0.88 
               E^((-0.2) (-30. + $CellContext`Nit/$CellContext`P)))/(1 + 
              E^((-0.2) (-30. + $CellContext`Nit/$CellContext`P)))) \
$CellContext`P == 0, "Tooltip"]& ], 
         TagBox[
          TooltipBox[
           {RGBColor[1, 0, 0], Thickness[0.01], LineBox[CompressedData["
1:eJwNz1k2QgEAANBXKkRESP21Jee0AQtglzI1UeYxlTESIQr34y7g5lbXV9ZC
QRDk2aDAJltss8MuRUqUqVBlj31q1DngkCOOOeGUM8654JIrrmlwQ5MWbW65
454HHnmiwzMvdHmlxxvv9Pngky8GfPPDkBG//BEIhwgzRoQoMcaZYJI4U0yT
YIZZkswxT4oFFlkizTIZsvwDUr821A==
             "]], LineBox[CompressedData["
1:eJwV0FdbgQEAgNGv36FBWkRDS5TZ1CQjLSWlNOT/33RcnOd5r99Id1j7nQiC
oEVITDLFNDOEiTBLlDnmWWCRJWLEWSZBkhVWWWOdFBtsssU2O6TZJUOWPfbJ
kadAkRJlDjjkiGNOOKXCGedccMkV11SpcUOdBk1a3NLmjnseeOSJDs+80OWV
Hm+80+eDTwZ88c0P46lD/hjxDxh6Giw=
             "]], LineBox[CompressedData["
1:eJwNxlVSQgEAAMDnUbySR3DGX5mxBTvBQhHsDiwUxe7uRuU87sfObHFpqKS8
KAiCMiqkkiqqqaGWOuoJE6GBRppopoVW2ming0666CZKjB566aOfAeIMMkSC
YZKkGGGUMcaZYJIppplhljnmWWCRJZZJs8Iqa6yzQYZNtsiyzQ45dtljnwMO
OeKYE04545wLLrnimhtuueOeBx554pkXXnnjnQ8++eKbPD/88keBfwhGQzI=

             "]]},
           RowBox[{
             RowBox[{
               RowBox[{"0.004`", "\[VeryThinSpace]"}], "-", 
               RowBox[{"0.01`", " ", "P"}], "+", 
               FractionBox[
                RowBox[{"0.35`", " ", 
                  SuperscriptBox["P", "2.`"]}], 
                RowBox[{
                  RowBox[{"100.`", "\[VeryThinSpace]"}], "+", 
                  SuperscriptBox["P", "2.`"]}]]}], "\[Equal]", "0"}]],
          
          Annotation[#, 
           0.004 - 0.01 $CellContext`P + 
            0.35 ($CellContext`P^2./(100. + $CellContext`P^2.)) == 0, 
           "Tooltip"]& ]}],
       AspectRatio->1,
       Frame->True,
       FrameLabel->{
         FormBox["\"N\"", TraditionalForm], 
         FormBox["\"P\"", TraditionalForm]},
       LabelStyle->Directive[
         GrayLevel[0], FontFamily -> "Helvetica", FontSize -> 14],
       PlotRange->{{0, 1200}, {0, 35}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {967.5, -193.5}, 
      ImageScaled[{0.5, 0.5}], {360., 360.}]}, {InsetBox[
      GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxdlwk0ldsbxpFE+svUaJ4jFQ4y5Ty6oTSQOVESlSGOeZ45hkxH462Qq+E2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        "], {{}, {}, 
         TagBox[
          TooltipBox[
           {RGBColor[0, 0, 1], Thickness[0.01], 
            LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 
             17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 
             33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 
             49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 
             65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 
             81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 
             97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 
             110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 
             123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 
             136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 
             149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 
             162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 
             175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 
             188, 189, 190, 191, 192, 193, 194, 195, 196, 197}]},
           RowBox[{
             RowBox[{
               RowBox[{"0.2`", "\[VeryThinSpace]"}], "-", 
               RowBox[{"0.01`", " ", "Nit"}], "+", 
               FractionBox[
                RowBox[{"0.88`", " ", 
                  SuperscriptBox["\[ExponentialE]", 
                   RowBox[{
                    RowBox[{"-", "0.2`"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "30.`"}], "+", 
                    FractionBox["Nit", "P"]}], ")"}]}]], " ", "P"}], 
                RowBox[{"1", "+", 
                  SuperscriptBox["\[ExponentialE]", 
                   RowBox[{
                    RowBox[{"-", "0.2`"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "30.`"}], "+", 
                    FractionBox["Nit", "P"]}], ")"}]}]]}]]}], "\[Equal]", 
             "0"}]],
          
          Annotation[#, 
           0.2 - 0.01 $CellContext`Nit + ((0.88 
               E^((-0.2) (-30. + $CellContext`Nit/$CellContext`P)))/(1 + 
              E^((-0.2) (-30. + $CellContext`Nit/$CellContext`P)))) \
$CellContext`P == 0, "Tooltip"]& ], 
         TagBox[
          TooltipBox[
           {RGBColor[1, 0, 0], Thickness[0.01], LineBox[CompressedData["
1:eJwNz2ciggEAANAvexXKJmmo+3SEDpBb2nsnsvfeIvR+vAO8ZGEqXwwFQVBg
mhlmmWOeBRZZYpkVVlljnQ022WKbHXYpsUeZfQ6ocMgRx5xwyhnnXHDJFdfc
cMsd9zzwyBPPvPDKG+988MkXVb75ocYvf/wTCIdooJEmmmmhlTba6aCTLsJE
6KaHXqLE6KOfAQYZYpgRRhkjzjgJJkiSIk2GSbLkqAO4Azib
             "]]},
           RowBox[{
             RowBox[{
               RowBox[{"0.008`", "\[VeryThinSpace]"}], "-", 
               RowBox[{"0.01`", " ", "P"}], "+", 
               FractionBox[
                RowBox[{"0.15`", " ", 
                  SuperscriptBox["P", "2.`"]}], 
                RowBox[{
                  RowBox[{"100.`", "\[VeryThinSpace]"}], "+", 
                  SuperscriptBox["P", "2.`"]}]]}], "\[Equal]", "0"}]],
          
          Annotation[#, 
           0.008 - 0.01 $CellContext`P + 
            0.15 ($CellContext`P^2./(100. + $CellContext`P^2.)) == 0, 
           "Tooltip"]& ]}],
       AspectRatio->1,
       Frame->True,
       FrameLabel->{
         FormBox["\"N\"", TraditionalForm], 
         FormBox["\"P\"", TraditionalForm]},
       LabelStyle->Directive[
         GrayLevel[0], FontFamily -> "Helvetica", FontSize -> 14],
       PlotRange->{{0, 1200}, {0, 35}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {193.5, -580.5}, 
      ImageScaled[{0.5, 0.5}], {360., 360.}], InsetBox[
      GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxdmAk0VVsYx5FkKBENCpllSLjIlPuRoTRQZo8oZOaaMkSua57v1SQVeV55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        "], {{}, {}, 
         TagBox[
          TooltipBox[
           {RGBColor[0, 0, 1], Thickness[0.01], 
            LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 
             17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 
             33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 
             49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 
             65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 
             81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 
             97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 
             110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 
             123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 
             136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 
             149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 
             162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 
             175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 
             188, 189, 190, 191, 192, 193, 194, 195, 196, 197}]},
           RowBox[{
             RowBox[{
               RowBox[{"0.2`", "\[VeryThinSpace]"}], "-", 
               RowBox[{"0.01`", " ", "Nit"}], "+", 
               FractionBox[
                RowBox[{"0.88`", " ", 
                  SuperscriptBox["\[ExponentialE]", 
                   RowBox[{
                    RowBox[{"-", "0.2`"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "30.`"}], "+", 
                    FractionBox["Nit", "P"]}], ")"}]}]], " ", "P"}], 
                RowBox[{"1", "+", 
                  SuperscriptBox["\[ExponentialE]", 
                   RowBox[{
                    RowBox[{"-", "0.2`"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "30.`"}], "+", 
                    FractionBox["Nit", "P"]}], ")"}]}]]}]]}], "\[Equal]", 
             "0"}]],
          
          Annotation[#, 
           0.2 - 0.01 $CellContext`Nit + ((0.88 
               E^((-0.2) (-30. + $CellContext`Nit/$CellContext`P)))/(1 + 
              E^((-0.2) (-30. + $CellContext`Nit/$CellContext`P)))) \
$CellContext`P == 0, "Tooltip"]& ], 
         TagBox[
          TooltipBox[
           {RGBColor[1, 0, 0], Thickness[0.01], LineBox[CompressedData["
1:eJwNz1k2QgEAANBXKkRESP21Jee0AQtglzI1UeYxlTESIQr34y7g5lbXV9ZC
QRDk2aDAJltss8MuRUqUqVBlj31q1DngkCOOOeGUM8654JIrrmlwQ5MWbW65
454HHnmiwzMvdHmlxxvv9Pngky8GfPPDkBG//BEIhwgzRoQoMcaZYJI4U0yT
YIZZkswxT4oFFlkizTIZsvwDUr821A==
             "]], LineBox[CompressedData["
1:eJwV0Fc7ggEAQOHP7zCz9whJQyV7S0JmGRmRnfLnvS7e5znXJ1Su5V5agiAo
0SraaKeDTroI0U0PvfTRzwCDDDHMCKOMMc4Ek0wRZpoZZokwR5R5YsRJkGSB
FGkyLJJliWVWWGWNdTbYZIttdthlj31yHJDnkAJHHHNCkVPOOOeCS64oUeaa
G265o8I9DzzyRJVn/qfWeOWNdz745Itv6vzQoMkvf6REHuE=
             "]], LineBox[CompressedData["
1:eJwNxmkyggEAANDPUbqSGRdwgFyAyJJESmkRsmTNlsgu2aJEHcn78WZeaHRs
ODwUBMEI4zJBhEmmiDLNDLPMEWOeOAskWGSJJMukSLNChiyr5MhToMgaJdbZ
YJMyW2yzwy4V9tjngEOOOKbKCaeccc4FNS6pc8U1DW645Y57HnjkiWeavNDi
lTfe+eCTNl9806HLDz1++aPPgH/q/Dl8
             "]]},
           RowBox[{
             RowBox[{
               RowBox[{"0.008`", "\[VeryThinSpace]"}], "-", 
               RowBox[{"0.01`", " ", "P"}], "+", 
               FractionBox[
                RowBox[{"0.25`", " ", 
                  SuperscriptBox["P", "2.`"]}], 
                RowBox[{
                  RowBox[{"100.`", "\[VeryThinSpace]"}], "+", 
                  SuperscriptBox["P", "2.`"]}]]}], "\[Equal]", "0"}]],
          
          Annotation[#, 
           0.008 - 0.01 $CellContext`P + 
            0.25 ($CellContext`P^2./(100. + $CellContext`P^2.)) == 0, 
           "Tooltip"]& ]}],
       AspectRatio->1,
       Frame->True,
       FrameLabel->{
         FormBox["\"N\"", TraditionalForm], 
         FormBox["\"P\"", TraditionalForm]},
       LabelStyle->Directive[
         GrayLevel[0], FontFamily -> "Helvetica", FontSize -> 14],
       PlotRange->{{0, 1200}, {0, 35}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {580.5, -580.5}, 
      ImageScaled[{0.5, 0.5}], {360., 360.}], InsetBox[
      GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxdVgk4VekfRrKkv2SpjCW7LAkX2XJfJi2qITsRWRJZrn3Pvma5V1MZZRst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        "], {{}, {}, 
         TagBox[
          TooltipBox[
           {RGBColor[0, 0, 1], Thickness[0.01], 
            LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 
             17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 
             33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 
             49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 
             65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 
             81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 
             97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 
             110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 
             123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 
             136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 
             149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 
             162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 
             175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 
             188, 189, 190, 191, 192, 193, 194, 195, 196, 197}]},
           RowBox[{
             RowBox[{
               RowBox[{"0.2`", "\[VeryThinSpace]"}], "-", 
               RowBox[{"0.01`", " ", "Nit"}], "+", 
               FractionBox[
                RowBox[{"0.88`", " ", 
                  SuperscriptBox["\[ExponentialE]", 
                   RowBox[{
                    RowBox[{"-", "0.2`"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "30.`"}], "+", 
                    FractionBox["Nit", "P"]}], ")"}]}]], " ", "P"}], 
                RowBox[{"1", "+", 
                  SuperscriptBox["\[ExponentialE]", 
                   RowBox[{
                    RowBox[{"-", "0.2`"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "30.`"}], "+", 
                    FractionBox["Nit", "P"]}], ")"}]}]]}]]}], "\[Equal]", 
             "0"}]],
          
          Annotation[#, 
           0.2 - 0.01 $CellContext`Nit + ((0.88 
               E^((-0.2) (-30. + $CellContext`Nit/$CellContext`P)))/(1 + 
              E^((-0.2) (-30. + $CellContext`Nit/$CellContext`P)))) \
$CellContext`P == 0, "Tooltip"]& ], 
         TagBox[
          TooltipBox[
           {RGBColor[1, 0, 0], Thickness[0.01], LineBox[CompressedData["
1:eJwNz1k2QgEAANBXkZCpSAnn2JI/vxbALhvMZc6UkIQQypz7cRdwF5ZXF1dC
QRAskSNPgSJrrLPBJltss0OJMrvssc8BhxxxTIUTTjnjnAuqXFLjimtuqHNL
gzua3PPAIy2eeOaFNq+88U6HLh988sU3P/zyR49AOESYCH30E2WAGIMMMUyc
EUYZY5wJEiSZZIoU06TJMEOWWeaY5x/KUDdO
             "]]},
           RowBox[{
             RowBox[{
               RowBox[{"0.008`", "\[VeryThinSpace]"}], "-", 
               RowBox[{"0.01`", " ", "P"}], "+", 
               FractionBox[
                RowBox[{"0.35`", " ", 
                  SuperscriptBox["P", "2.`"]}], 
                RowBox[{
                  RowBox[{"100.`", "\[VeryThinSpace]"}], "+", 
                  SuperscriptBox["P", "2.`"]}]]}], "\[Equal]", "0"}]],
          
          Annotation[#, 
           0.008 - 0.01 $CellContext`P + 
            0.35 ($CellContext`P^2./(100. + $CellContext`P^2.)) == 0, 
           "Tooltip"]& ]}],
       AspectRatio->1,
       Frame->True,
       FrameLabel->{
         FormBox["\"N\"", TraditionalForm], 
         FormBox["\"P\"", TraditionalForm]},
       LabelStyle->Directive[
         GrayLevel[0], FontFamily -> "Helvetica", FontSize -> 14],
       PlotRange->{{0, 1200}, {0, 35}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {967.5, -580.5}, 
      ImageScaled[{0.5, 0.5}], {360., 360.}]}, {InsetBox[
      GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxdmAk4VWkYx5EsKZUkCtllSZeLbLl/JirVkJ0UQnauPUvZryXLvZr2bKNl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        "], {{}, {}, 
         TagBox[
          TooltipBox[
           {RGBColor[0, 0, 1], Thickness[0.01], 
            LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 
             17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 
             33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 
             49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 
             65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 
             81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 
             97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 
             110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 
             123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 
             136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 
             149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 
             162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 
             175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 
             188, 189, 190, 191, 192, 193, 194, 195, 196, 197}]},
           RowBox[{
             RowBox[{
               RowBox[{"0.2`", "\[VeryThinSpace]"}], "-", 
               RowBox[{"0.01`", " ", "Nit"}], "+", 
               FractionBox[
                RowBox[{"0.88`", " ", 
                  SuperscriptBox["\[ExponentialE]", 
                   RowBox[{
                    RowBox[{"-", "0.2`"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "30.`"}], "+", 
                    FractionBox["Nit", "P"]}], ")"}]}]], " ", "P"}], 
                RowBox[{"1", "+", 
                  SuperscriptBox["\[ExponentialE]", 
                   RowBox[{
                    RowBox[{"-", "0.2`"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "30.`"}], "+", 
                    FractionBox["Nit", "P"]}], ")"}]}]]}]]}], "\[Equal]", 
             "0"}]],
          
          Annotation[#, 
           0.2 - 0.01 $CellContext`Nit + ((0.88 
               E^((-0.2) (-30. + $CellContext`Nit/$CellContext`P)))/(1 + 
              E^((-0.2) (-30. + $CellContext`Nit/$CellContext`P)))) \
$CellContext`P == 0, "Tooltip"]& ], 
         TagBox[
          TooltipBox[
           {RGBColor[1, 0, 0], Thickness[0.01], LineBox[CompressedData["
1:eJwNz2ciggEAANAvexXKJmmo+3SEDpBb2nsnsvfeIvR+vAO8ZGEqXwwFQVBg
mhlmmWOeBRZZYpkVVlljnQ022WKbHXYpsUeZfQ6ocMgRx5xwyhnnXHDJFdfc
cMsd9zzwyBPPvPDKG+988MkXVb75ocYvf/wTCIdooJEmmmmhlTba6aCTLsJE
6KaHXqLE6KOfAQYZYpgRRhkjzjgJJkiSIk2GSbLkqAO4Azib
             "]]},
           RowBox[{
             RowBox[{
               RowBox[{"0.012`", "\[VeryThinSpace]"}], "-", 
               RowBox[{"0.01`", " ", "P"}], "+", 
               FractionBox[
                RowBox[{"0.15`", " ", 
                  SuperscriptBox["P", "2.`"]}], 
                RowBox[{
                  RowBox[{"100.`", "\[VeryThinSpace]"}], "+", 
                  SuperscriptBox["P", "2.`"]}]]}], "\[Equal]", "0"}]],
          
          Annotation[#, 
           0.012 - 0.01 $CellContext`P + 
            0.15 ($CellContext`P^2./(100. + $CellContext`P^2.)) == 0, 
           "Tooltip"]& ]}],
       AspectRatio->1,
       Frame->True,
       FrameLabel->{
         FormBox["\"N\"", TraditionalForm], 
         FormBox["\"P\"", TraditionalForm]},
       LabelStyle->Directive[
         GrayLevel[0], FontFamily -> "Helvetica", FontSize -> 14],
       PlotRange->{{0, 1200}, {0, 35}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {193.5, -967.5}, 
      ImageScaled[{0.5, 0.5}], {360., 360.}], InsetBox[
      GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxdlgk4lekbxpEsaSSkxb4vSTjIlnMzoZSh7IaSJTtHtsh67OJwtEnZxpSp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        "], {{}, {}, 
         TagBox[
          TooltipBox[
           {RGBColor[0, 0, 1], Thickness[0.01], 
            LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 
             17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 
             33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 
             49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 
             65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 
             81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 
             97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 
             110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 
             123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 
             136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 
             149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 
             162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 
             175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 
             188, 189, 190, 191, 192, 193, 194, 195, 196, 197}]},
           RowBox[{
             RowBox[{
               RowBox[{"0.2`", "\[VeryThinSpace]"}], "-", 
               RowBox[{"0.01`", " ", "Nit"}], "+", 
               FractionBox[
                RowBox[{"0.88`", " ", 
                  SuperscriptBox["\[ExponentialE]", 
                   RowBox[{
                    RowBox[{"-", "0.2`"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "30.`"}], "+", 
                    FractionBox["Nit", "P"]}], ")"}]}]], " ", "P"}], 
                RowBox[{"1", "+", 
                  SuperscriptBox["\[ExponentialE]", 
                   RowBox[{
                    RowBox[{"-", "0.2`"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "30.`"}], "+", 
                    FractionBox["Nit", "P"]}], ")"}]}]]}]]}], "\[Equal]", 
             "0"}]],
          
          Annotation[#, 
           0.2 - 0.01 $CellContext`Nit + ((0.88 
               E^((-0.2) (-30. + $CellContext`Nit/$CellContext`P)))/(1 + 
              E^((-0.2) (-30. + $CellContext`Nit/$CellContext`P)))) \
$CellContext`P == 0, "Tooltip"]& ], 
         TagBox[
          TooltipBox[
           {RGBColor[1, 0, 0], Thickness[0.01], LineBox[CompressedData["
1:eJwNz1k2QgEAANBXKkRESP21Jee0AQtglzI1UeYxlTESIQr34y7g5lbXV9ZC
QRDk2aDAJltss8MuRUqUqVBlj31q1DngkCOOOeGUM8654JIrrmlwQ5MWbW65
454HHnmiwzMvdHmlxxvv9Pngky8GfPPDkBG//BEIhwgzRoQoMcaZYJI4U0yT
YIZZkswxT4oFFlkizTIZsvwDUr821A==
             "]]},
           RowBox[{
             RowBox[{
               RowBox[{"0.012`", "\[VeryThinSpace]"}], "-", 
               RowBox[{"0.01`", " ", "P"}], "+", 
               FractionBox[
                RowBox[{"0.25`", " ", 
                  SuperscriptBox["P", "2.`"]}], 
                RowBox[{
                  RowBox[{"100.`", "\[VeryThinSpace]"}], "+", 
                  SuperscriptBox["P", "2.`"]}]]}], "\[Equal]", "0"}]],
          
          Annotation[#, 
           0.012 - 0.01 $CellContext`P + 
            0.25 ($CellContext`P^2./(100. + $CellContext`P^2.)) == 0, 
           "Tooltip"]& ]}],
       AspectRatio->1,
       Frame->True,
       FrameLabel->{
         FormBox["\"N\"", TraditionalForm], 
         FormBox["\"P\"", TraditionalForm]},
       LabelStyle->Directive[
         GrayLevel[0], FontFamily -> "Helvetica", FontSize -> 14],
       PlotRange->{{0, 1200}, {0, 35}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {580.5, -967.5}, 
      ImageScaled[{0.5, 0.5}], {360., 360.}], InsetBox[
      GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxdmAk0VesbxpFkKGVoFClT5uEgU+c8FEm5yBCuQsg8ZSgyHrNMR5Mr4xVu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        "], {{}, {}, 
         TagBox[
          TooltipBox[
           {RGBColor[0, 0, 1], Thickness[0.01], 
            LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 
             17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 
             33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 
             49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 
             65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 
             81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 
             97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 
             110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 
             123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 
             136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 
             149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 
             162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 
             175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 
             188, 189, 190, 191, 192, 193, 194, 195, 196, 197}]},
           RowBox[{
             RowBox[{
               RowBox[{"0.2`", "\[VeryThinSpace]"}], "-", 
               RowBox[{"0.01`", " ", "Nit"}], "+", 
               FractionBox[
                RowBox[{"0.88`", " ", 
                  SuperscriptBox["\[ExponentialE]", 
                   RowBox[{
                    RowBox[{"-", "0.2`"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "30.`"}], "+", 
                    FractionBox["Nit", "P"]}], ")"}]}]], " ", "P"}], 
                RowBox[{"1", "+", 
                  SuperscriptBox["\[ExponentialE]", 
                   RowBox[{
                    RowBox[{"-", "0.2`"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "30.`"}], "+", 
                    FractionBox["Nit", "P"]}], ")"}]}]]}]]}], "\[Equal]", 
             "0"}]],
          
          Annotation[#, 
           0.2 - 0.01 $CellContext`Nit + ((0.88 
               E^((-0.2) (-30. + $CellContext`Nit/$CellContext`P)))/(1 + 
              E^((-0.2) (-30. + $CellContext`Nit/$CellContext`P)))) \
$CellContext`P == 0, "Tooltip"]& ], 
         TagBox[
          TooltipBox[
           {RGBColor[1, 0, 0], Thickness[0.01], LineBox[CompressedData["
1:eJwNz2ciggEAANAvexXKJmmo+3SEDpBb2nsnsvfeIvR+vAO8ZGEqXwwFQVBg
mhlmmWOeBRZZYpkVVlljnQ022WKbHXYpsUeZfQ6ocMgRx5xwyhnnXHDJFdfc
cMsd9zzwyBPPvPDKG+988MkXVb75ocYvf/wTCIdooJEmmmmhlTba6aCTLsJE
6KaHXqLE6KOfAQYZYpgRRhkjzjgJJkiSIk2GSbLkqAO4Azib
             "]]},
           RowBox[{
             RowBox[{
               RowBox[{"0.012`", "\[VeryThinSpace]"}], "-", 
               RowBox[{"0.01`", " ", "P"}], "+", 
               FractionBox[
                RowBox[{"0.35`", " ", 
                  SuperscriptBox["P", "2.`"]}], 
                RowBox[{
                  RowBox[{"100.`", "\[VeryThinSpace]"}], "+", 
                  SuperscriptBox["P", "2.`"]}]]}], "\[Equal]", "0"}]],
          
          Annotation[#, 
           0.012 - 0.01 $CellContext`P + 
            0.35 ($CellContext`P^2./(100. + $CellContext`P^2.)) == 0, 
           "Tooltip"]& ]}],
       AspectRatio->1,
       Frame->True,
       FrameLabel->{
         FormBox["\"N\"", TraditionalForm], 
         FormBox["\"P\"", TraditionalForm]},
       LabelStyle->Directive[
         GrayLevel[0], FontFamily -> "Helvetica", FontSize -> 14],
       PlotRange->{{0, 1200}, {0, 35}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {967.5, -967.5}, 
      ImageScaled[{0.5, 0.5}], {360., 360.}]}}, {}},
  ContentSelectable->True,
  ImageSize->{777., Automatic},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.564405347279205*^9, 3.5644055182899113`*^9, 
  3.564405604857911*^9, 3.5644060872581644`*^9}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.564351362201788*^9, 3.5643513667104273`*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{3.564351523747459*^9}]
}, Open  ]]
},
WindowSize->{1280, 1002},
WindowMargins->{{Automatic, 0}, {Automatic, 0}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
FrontEndVersion->"10.0 for Microsoft Windows (64-bit) (July 1, 2014)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 1055, 22, 334, "Text"],
Cell[CellGroupData[{
Cell[1637, 46, 3571, 95, 403, "Input"],
Cell[5211, 143, 419, 8, 21, "Message"],
Cell[5633, 153, 8009, 155, 367, "Output"],
Cell[13645, 310, 95, 1, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13777, 316, 3571, 95, 403, "Input"],
Cell[17351, 413, 416, 8, 21, "Message"],
Cell[17770, 423, 10042, 190, 367, "Output"],
Cell[27815, 615, 95, 1, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27947, 621, 3516, 94, 403, "Input"],
Cell[31466, 717, 419, 8, 21, "Message"],
Cell[31888, 727, 10063, 191, 367, "Output"],
Cell[41954, 920, 93, 1, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42084, 926, 3518, 94, 403, "Input"],
Cell[45605, 1022, 441, 8, 21, "Message"],
Cell[46049, 1032, 7998, 154, 367, "Output"],
Cell[54050, 1188, 121, 1, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[54208, 1194, 3455, 94, 403, "Input"],
Cell[57666, 1290, 10017, 189, 367, "Output"],
Cell[67686, 1481, 120, 1, 31, "Output"]
}, Open  ]],
Cell[67821, 1485, 94, 1, 31, "Input"],
Cell[CellGroupData[{
Cell[67940, 1490, 3472, 93, 403, "Input"],
Cell[71415, 1585, 443, 8, 21, "Message"],
Cell[71861, 1595, 7886, 152, 367, "Output"],
Cell[79750, 1749, 119, 1, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[79906, 1755, 3518, 94, 403, "Input"],
Cell[83427, 1851, 417, 8, 21, "Message"],
Cell[83847, 1861, 7980, 154, 367, "Output"],
Cell[91830, 2017, 97, 1, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[91964, 2023, 3569, 95, 403, "Input"],
Cell[95536, 2120, 419, 8, 21, "Message"],
Cell[95958, 2130, 7830, 152, 367, "Output"],
Cell[103791, 2284, 95, 1, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[103923, 2290, 3569, 95, 403, "Input"],
Cell[107495, 2387, 417, 8, 21, "Message"],
Cell[107915, 2397, 7976, 154, 367, "Output"],
Cell[115894, 2553, 97, 1, 31, "Output"]
}, Open  ]],
Cell[116006, 2557, 96, 1, 31, "Input"],
Cell[116105, 2560, 420, 6, 30, "Text"],
Cell[116528, 2568, 759, 16, 72, "Input"],
Cell[CellGroupData[{
Cell[117312, 2588, 19, 0, 70, "Section"],
Cell[117334, 2590, 81416, 1524, 792, "Output"],
Cell[198753, 4116, 94, 1, 31, "Input"],
Cell[198850, 4119, 68, 1, 31, "Input"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
